<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Activar el plugin',
'affichage' => 'Compaxinaci&oacute;n',
'aide_non_disponible' => 'Esta parte de l\'aida en ll&iacute;nia tov&iacute;a nun t&aacute; iguada n\'esta llingua.',
'auteur' => 'Autor:',
'avis_acces_interdit' => 'Accesu torgau.',
'avis_article_modifie' => 'Atenci&oacute;n, @nom_auteur_modif@ trabay&oacute; n\'esti art&iacute;culo hai @date_diff@ minutos.',
'avis_aucun_resultat' => 'Deng&uacute;n result&aacute;u',
'avis_chemin_invalide_1' => 'El cam&iacute;n escoy&iacute;u',
'avis_chemin_invalide_2' => 'nun paez afaya&iacute;zu. Torna a la p&aacute;xina anterior y revisa la informaci&oacute;n qu\'escribiste.',
'avis_connexion_echec_1' => 'Fall&oacute; l\'enxertu al servidor SQL.',
'avis_connexion_echec_2' => 'Torna a la p&aacute;xina cabera y revisa los datos que pusiste.',
'avis_connexion_echec_3' => '<b>Nota:</b> En munchos sirvidores, fai falta <b>pidir</b> la activaci&oacute;n del accesu a la base de datos enantes de poder usala. Si nun puedes conectate, mira si ficiste esi tr&aacute;mite.',
'avis_connexion_ldap_echec_1' => 'Hubo un fallu na conex&oacute;n al sirvidor LDAP.',
'avis_connexion_ldap_echec_2' => 'Torna a la p&aacute;xina anterior, y revisa la informaci&oacute;n qu\'escribisti n\'ella.',
'avis_connexion_ldap_echec_3' => 'D\'otru mou, nun uses el sofitu de LDAP pa importar usuarios.',
'avis_conseil_selection_mot_cle' => '<b>Grupu importante:</b> s\'encamienta fonderamente escoyer una pallabra-clave pa esti grupu.',
'avis_deplacement_rubrique' => '&iexcl;Atenci&oacute;n! Esta estaya conti&eacute;n @contient_breves@ breve@scb@: si la mueves, ties que marcar esti cuadru de confirmaci&oacute;n.',
'avis_destinataire_obligatoire' => 'Ties qu\'indicar un destinatariu enantes d\'unviar esti mensaxe.',
'avis_doublon_mot_cle' => 'Un mot existe deja avec ce titre. &Ecirc;tes vous s&ucirc;r de vouloir cr&eacute;er le m&ecirc;me ?', # NEW
'avis_erreur_connexion_mysql' => 'Fallu de conex&oacute;n SQL',
'avis_erreur_version_archive' => '<b>&iexcl;Atenci&oacute;n! L\'archivu @archive@ concasa con
    otra versi&oacute;n de SPIP distinta de la que ta
    instalada.</b> Enfrenteste con dificult&aacute;es
    enforma: peligru de destruir la base de datos,
    fallos variaos nel funcionamientu del sitiu, etc.
    Nun valides esta petici&oacute;n d\'importaci&oacute;n.<p>Pa
    mayor informaci&oacute;n, llee <a href="@spipnet@">
                                la documentaci&oacute;n de SPIP</a>.</p>', # MODIF
'avis_espace_interdit' => '<b>Espaciu torg&aacute;u</b><div>SPIP ya ta instalao.</div>',
'avis_lecture_noms_bases_1' => 'El programa d\'instalaci&oacute;n nun fue a lleer los nomes de les bases de datos instal&aacute;es.',
'avis_lecture_noms_bases_2' => 'Puede ser que denguna base nun te disponible, o que la funci&oacute;n que permite llistar les bases te desactivada
 por cuenta de razones de segurid&aacute; (lo que ye\'l casu n\'abondos agospiamientos web).',
'avis_lecture_noms_bases_3' => 'Nel segundu casu, ye probable qu\'esista una base que col mesmu nome qu\'el to login:',
'avis_non_acces_message' => 'Nun tienes accesu a esti mensaxe.',
'avis_non_acces_page' => 'Nun tienes accesu a esta p&aacute;xina.',
'avis_operation_echec' => 'Fall&oacute; la operaci&oacute;n.',
'avis_operation_impossible' => 'Operaci&oacute;n imposible',
'avis_probleme_archive' => 'Problema de llectura del archivu @archive@',
'avis_site_introuvable' => 'Nun s\'atopa el sitiu',
'avis_site_syndique_probleme' => 'Atenci&oacute;n: la sindicaci&oacute;n de esti sitiu atopose con un problema; poro, el sistema ta interrump&iacute;u de momentu. Verifica les se&ntilde;es del archivu de sindicaci&oacute;n del sitiu (<b>@url_syndic@</b>), y tenta recuperar otra vegada la informaci&oacute;n.',
'avis_sites_probleme_syndication' => 'Hubo un problema cola sindicaci&oacute;n d\'estos sitios',
'avis_sites_syndiques_probleme' => 'Estos sitios sindicaos tuvieron problemes',
'avis_suppression_base' => 'ATENCI&Oacute;N, el desaniciu de los datos nun ye reversible',
'avis_version_mysql' => 'El to sirvidor SQL (@version_mysql@) nun permite la igua autom&aacute;tica de les tables de la base.',

// B
'bouton_acces_ldap' => 'A&ntilde;ader l\'accesu a LDAP',
'bouton_ajouter' => 'Amestar',
'bouton_ajouter_participant' => 'A&Ntilde;ADER UN PARTICIPANTE:',
'bouton_annonce' => 'ANUNCIU',
'bouton_annuler' => 'Anular',
'bouton_checkbox_envoi_message' => 'posibilid&aacute; d\'unviar un mensaxe',
'bouton_checkbox_indiquer_site' => 'poner obligatoriamente un sitiu Web',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'los y les alministradores del sitiu',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Los y les redactores',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'los visitantes del sitiu p&uacute;blicu cuando pongan un mensaxe nun foru',
'bouton_checkbox_signature_unique_email' => 'una sola firma por corr&eacute;u electr&oacute;nicu',
'bouton_checkbox_signature_unique_site' => 'una sola firma por sitiu Web',
'bouton_demande_publication' => 'Pedir l\'espublizamientu d\'esti art&iacute;culu',
'bouton_desactive_tout' => 'Desactivalo too',
'bouton_desinstaller' => 'Desasitiar',
'bouton_effacer_index' => 'Desaniciar los &iacute;ndices',
'bouton_effacer_statistiques' => 'Desaniciar les estad&iacute;stiques',
'bouton_effacer_tout' => 'Desaniciar TOO',
'bouton_envoi_message_02' => 'UNVIAR UN MENSAXE',
'bouton_envoyer_message' => 'Mensaxe definitivu: unviar',
'bouton_forum_petition' => 'FORU &amp; SOLICIT&Uacute;',
'bouton_modifier' => 'Camudar',
'bouton_pense_bete' => 'RECORDATORIU PERSONAL',
'bouton_radio_activer_messagerie' => 'Activar la mensaxeria interna',
'bouton_radio_activer_messagerie_interne' => 'Activar la mensaxer&iacute;a interna',
'bouton_radio_activer_petition' => 'Activar la solicit&uacute;',
'bouton_radio_afficher' => 'Amosar',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Apaecer na llista de redactores coneutaos',
'bouton_radio_articles_futurs' => 's&oacute;lo pa los art&iacute;culos futuros (ensin actuar so la base de datos).',
'bouton_radio_articles_tous' => 'pa tolos art&iacute;culos ensin esceici&oacute;n.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'pa tolos art&iacute;culos, menos los que tengan el foru desactiv&aacute;u.',
'bouton_radio_desactiver_messagerie' => 'Desactivar la mensaxer&iacute;a',
'bouton_radio_enregistrement_obligatoire' => 'Rexistru obligatoriu (los usuarios
  tienen que abonase coles sos se&ntilde;es d\'e-mail enantes
  de que puedan escribir les sos contribuciones).',
'bouton_radio_envoi_annonces_adresse' => 'Unviar los anuncios a la direici&oacute;n:',
'bouton_radio_envoi_liste_nouveautes' => 'Unviar la llista de noved&aacute;es',
'bouton_radio_moderation_priori' => 'Moderaci&oacute;n a priori (les contribuciones
 nun apaecer&aacute;n en p&uacute;blicu hasta que les validen
 los alministradores).',
'bouton_radio_modere_abonnement' => 'pa abon&aacute;os',
'bouton_radio_modere_posteriori' => 'moderaci&oacute;n a posteriori',
'bouton_radio_modere_priori' => 'moderaci&oacute;n a priori',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Nun apaecer na llista de redactores',
'bouton_radio_non_envoi_annonces_editoriales' => 'Nun mandar anuncios editoriales',
'bouton_radio_non_syndication' => 'Ensin sindicaci&oacute;n',
'bouton_radio_pas_petition' => 'Ensin solicit&uacute;',
'bouton_radio_petition_activee' => 'Solicit&uacute; activada',
'bouton_radio_publication_immediate' => 'Espublizar d\'inmediatu los mensaxes
 (les contribuciones s\'amuesen desque s\'unv&iacute;en, los alministradores pueden
 desaniciales llueu).',
'bouton_radio_sauvegarde_compressee' => 'copia de segurid&aacute; comprimida en @fichier@',
'bouton_radio_sauvegarde_non_compressee' => 'copia de segurid&aacute; nun comprimida en @fichier@',
'bouton_radio_supprimer_petition' => 'Desaniciar la solicit&uacute;',
'bouton_radio_syndication' => 'Sindicaci&oacute;n:',
'bouton_redirection' => 'REDIREICI&Oacute;N',
'bouton_relancer_installation' => 'Rellanzar l\'instalaci&oacute;n',
'bouton_restaurer_base' => 'Restaurar la base',
'bouton_suivant' => 'Siguiente',
'bouton_tenter_recuperation' => 'Tentar una reparaci&oacute;n',
'bouton_test_proxy' => 'Comprobar el proxy',
'bouton_vider_cache' => 'Vaciar la cach&eacute;',
'bouton_voir_message' => 'Ver esti mensaxe enantes de validalu',

// C
'cache_mode_compresse' => 'Los archivos de la cach&eacute; gr&aacute;bense en mou comprim&iacute;u.',
'cache_mode_non_compresse' => 'Los archivos de la cach&eacute; gr&aacute;bense en mou nun comprim&iacute;u.',
'cache_modifiable_webmestre' => 'Esti par&aacute;metru puede modificase pol webmaster del sitiu.',
'calendrier_synchro' => 'Si uses un programa d\'axenda compatible <b>iCal</b>, puedes sincronizalu cola informaci&oacute;n d\'esti sitiu.',
'config_activer_champs' => 'Activar los campos siguientes',
'config_choix_base_sup' => 'indicar una base datos nesti sirvidor',
'config_erreur_base_sup' => 'SPIP nun tien accesu a la llista de les bases disponibles',
'config_info_base_sup' => 'Si tienes otres bases de datos pa restolar al travi&eacute;s de SPIP, col so sirvidor SQL o con otru, el formulariu d\'embaxo va permitite declarales. Si dexes ciertos campos vac&iacute;os, utilizar&aacute;nse les identificaciones de conex&oacute;n a la base principal.',
'config_info_base_sup_disponibles' => 'Bases suplementaries que ya son restolables:',
'config_info_enregistree' => 'Guardose la nueva configuraci&oacute;n',
'config_info_logos' => 'Cada elementu del sitiu puede tener un logo, lo mesmo qu\'un &laquo;logo de pasu\'l mur&raquo;',
'config_info_logos_utiliser' => 'Usar los logos',
'config_info_logos_utiliser_non' => 'Nun usar los logos',
'config_info_logos_utiliser_survol' => 'Usar los logos de pasu\'l mur',
'config_info_logos_utiliser_survol_non' => 'Nun usar los logos de pasu\'l mur',
'config_info_redirection' => 'En activando esta opci&oacute;n, vas poder crear art&iacute;culos virtuales, simples referencies d\'art&iacute;culos espubliz&aacute;os n\'otros sitios o fechos ensin SPIP.',
'config_redirection' => 'Art&iacute;culos virtuales',
'config_titre_base_sup' => 'Declaraci&oacute;n d\'una base suplementaria',
'config_titre_base_sup_choix' => 'Escueye una base suplementaria',
'connexion_ldap' => 'Conex&oacute;n:',
'copier_en_local' => 'Copiar en llocal',

// D
'date_mot_heures' => 'hores',
'diff_para_ajoute' => 'P&aacute;rrafu amestau',
'diff_para_deplace' => 'P&aacute;rrafu mov&iacute;u',
'diff_para_supprime' => 'P&aacute;rrafu desaniciau',
'diff_texte_ajoute' => 'Testu amestau',
'diff_texte_deplace' => 'Testu mov&iacute;u',
'diff_texte_supprime' => 'Testu desaniciau',
'double_clic_inserer_doc' => 'Fai doble-clic pa amestar esti atayu al testu',

// E
'email' => 'corr&eacute;u electr&oacute;nicu',
'email_2' => 'correu elletr&oacute;nicu:',
'en_savoir_plus' => 'En savoir plus', # NEW
'entree_adresse_annuaire' => 'Se&ntilde;es de l\'anuariu',
'entree_adresse_email' => 'Les tos se&ntilde;es d\'email',
'entree_adresse_fichier_syndication' => 'Se&ntilde;es de l\'archivu de sindicaci&oacute;n:',
'entree_adresse_site' => '<b>Se&ntilde;es del sitiu</b> [Obligatorio]',
'entree_base_donnee_1' => 'Se&ntilde;es de la base de datos',
'entree_base_donnee_2' => '(Bien de veces estes se&ntilde;es correspuendense coles del sitiu mesmu, dacuando son el nome &laquo;localhost&raquo;, o sinon dexense vac&iacute;es dafechu.)',
'entree_biographie' => 'Biograf&iacute;a curtia en delles pallabres.',
'entree_breve_publiee' => '&iquest;Hai qu\'espublizar esta breve?',
'entree_chemin_acces' => '<b>Enxertar</b> la ruta d\'accesu:',
'entree_cle_pgp' => 'La to clave PGP',
'entree_contenu_rubrique' => '(Conten&iacute;u de la estaya en delles pallabres.)',
'entree_description_site' => 'Descripci&oacute;n del sitiu',
'entree_identifiants_connexion' => 'Los identificadores pa la to conex&oacute;n...',
'entree_informations_connexion_ldap' => 'Nesti formulariu has d\'enxertar la informaci&oacute;n pa coneutate al sirvidor de se&ntilde;es LDAP.
 Esta informaci&oacute;n tien que apurr&iacute;tela l\'alministrador del sistema,
 o de la rede.',
'entree_infos_perso' => '&iquest;Qui&eacute;n yes?',
'entree_interieur_rubrique' => 'Dientro de l\'estaya:',
'entree_liens_sites' => '<b>Enllaz d\'hipertestu</b> (referencia, sitiu a visitar...)',
'entree_login' => 'El to login',
'entree_login_connexion_1' => 'El nome de conex&oacute;n',
'entree_login_connexion_2' => '(Correspuende seique al to nome d\'accesu al FTP; seique en blancu)',
'entree_login_ldap' => 'Nome inicial LDAP',
'entree_mot_passe' => 'La to contrase&ntilde;a',
'entree_mot_passe_1' => 'La contrase&ntilde;a pa la conex&oacute;n',
'entree_mot_passe_2' => '(Correspuende seique a la to contrase&ntilde;a pal FTP; seique en blancu)',
'entree_nom_fichier' => 'Has d\'amestar el nome de l\'archivu @texte_compresse@:',
'entree_nom_pseudo' => 'El to nome o nomatu',
'entree_nom_pseudo_1' => '(El to nome o nomatu)',
'entree_nom_site' => 'Nome del to sitiu web',
'entree_nouveau_passe' => 'Contrase&ntilde;a nueva',
'entree_passe_ldap' => 'Contrase&ntilde;a',
'entree_port_annuaire' => 'N&uacute;mberu de puertu del sirvidor de se&ntilde;es',
'entree_signature' => 'Robla',
'entree_texte_breve' => 'Testu de la breve',
'entree_titre_obligatoire' => '<b>T&iacute;tulu</b> [Obligatoriu]<br />',
'entree_url' => 'Les se&ntilde;es (URL) del to sitiu web',
'erreur_plugin_desinstalation_echouee' => 'La d&eacute;sinstallation du plugin a echou&eacute;. Vous pouvez n&eacute;anmoins le desactiver.', # NEW
'erreur_plugin_fichier_absent' => 'Falta l\'archivu',
'erreur_plugin_fichier_def_absent' => 'Falta l\'archivu de definici&oacute;n',
'erreur_plugin_nom_fonction_interdit' => 'Nome de funci&oacute;n encaboxada',
'erreur_plugin_nom_manquant' => 'Falta\'l nome del plugin',
'erreur_plugin_prefix_manquant' => 'Espaciu de nomes del plugin nun defin&iacute;u',
'erreur_plugin_tag_plugin_absent' => 'Falta el &lt;plugin&gt; nel archivu de definici&oacute;n',
'erreur_plugin_version_manquant' => 'Falta la versi&oacute;n del plugin',

// F
'forum_info_original' => 'orixinal',

// H
'htaccess_a_simuler' => 'Avertissement: la configuration de votre serveur HTTP ne tient pas compte des fichiers @htaccess@. Pour pouvoir assurer une bonne s&eacute;curit&eacute;, il faut que vous modifiez cette configuration sur ce point, ou bien que les constantes @constantes@ (d&eacute;finissables dans le fichier mes_options.php) aient comme valeur des r&eacute;pertoires en dehors de @document_root@.', # NEW
'htaccess_inoperant' => 'htaccess inop&eacute;rant', # NEW

// I
'ical_info1' => 'N\'esta p&aacute;xina ufrense delles maneres de tar en contautu cola activid&aacute; d\'esti sitiu.',
'ical_info2' => 'Pa m&aacute;s informaci&oacute;n tocante a toes estes t&eacute;cniques, pues consultar <a href="@spipnet@">la documentaci&oacute;n de SPIP</a>.',
'ical_info_calendrier' => 'Tienes dos axendes a la to disposici&oacute;n. La primera ye el plan del sitiu que anuncia tolos art&iacute;culos espublizaos. La segunda conti&eacute;n los anuncios editoriales y tambi&eacute;n los tos caberos mensaxes privaos: esta ye una axenda privada gracies a una clave personal, que pues modificar en tou momentu anovando la to contrase&ntilde;a.',
'ical_lien_rss_breves' => 'Sindicaci&oacute;n de les breves del sitiu',
'ical_methode_http' => 'Descarga',
'ical_methode_webcal' => 'Sincronizaci&oacute;n (webcal://)',
'ical_texte_js' => 'Una llinia de javascript va permitite amosar de mou bien f&aacute;cil, en cualquier otru sitiu tuyu, los art&iacute;culos recientes espublizaos nesti sitiu.',
'ical_texte_prive' => 'Esta axenda, de usu esclusivamente personal, te informa de l\'activid&aacute; editorial privada d\'esti sitiu (xeres y conceyos personales, art&iacute;culos y breves propuestos...).',
'ical_texte_public' => 'Esta axenda te permite siguir l\'activid&aacute; p&uacute;blica d\'esti sitiu (art&iacute;culos y breves espubliz&aacute;os).',
'ical_texte_rss' => 'Puedes sindicar les noved&aacute;es d\'esti sitiu en cualisquier llector d\'archivos en formatu XML/RSS (Rich Site Summary). Esti ye tambi&eacute;n el formatu que permite a SPIP lleer les noved&aacute;es espubliz&aacute;es n\'otros sitios que utilicen un formatu d\'intercamb&eacute;u compatible (sitios sindicaos).',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Llista de corr&eacute;u',
'ical_titre_rss' => 'Archivos de sindicaci&oacute;n',
'icone_activer_cookie' => 'Activar la cookie de correspondencia',
'icone_admin_plugin' => 'Xesti&oacute;n de los plugins',
'icone_afficher_auteurs' => 'Amosar los autores',
'icone_afficher_visiteurs' => 'Amosar les visites',
'icone_arret_discussion' => 'Nun participar ya nesta discusi&oacute;n',
'icone_calendrier' => 'Calendariu',
'icone_creation_groupe_mots' => 'Crear un nuevu grupu de pallabres',
'icone_creation_mots_cles' => 'Crear una nueva pallabra-clave',
'icone_creer_auteur' => 'Crear un nuevu autor y asocialu con esti art&iacute;culu',
'icone_creer_mot_cle' => 'Crear una nueva pallabra-clave y amestala con esti art&iacute;culu',
'icone_creer_mot_cle_breve' => 'Crear una nueva pallabra-clave y lligala con esta breve',
'icone_creer_mot_cle_rubrique' => 'Crear una nueva pallabra-clave y enllazala con esta estaya',
'icone_creer_mot_cle_site' => 'Crear una nueva pallabra-clave y enllazala con esti sitiu',
'icone_creer_rubrique_2' => 'Facer una estaya nueva',
'icone_ecrire_nouvel_article' => 'Les breves conten&iacute;es nesta estaya',
'icone_envoyer_message' => 'Unviar esti mensaxe',
'icone_evolution_visites' => 'Evoluci&oacute;n de les visites<br />@visites@ visites',
'icone_modif_groupe_mots' => 'Cambear esti grupu de pallabres',
'icone_modifier_article' => 'Iguar esti art&iacute;culu',
'icone_modifier_breve' => 'Iguar esta breve',
'icone_modifier_message' => 'Iguar esti mensaxe',
'icone_modifier_mot' => 'Iguar esta pallabra',
'icone_modifier_rubrique' => 'Iguar esta estaya',
'icone_modifier_site' => 'Iguar esti sitiu',
'icone_poster_message' => 'Unviar un mensaxe',
'icone_publier_breve' => 'Espublizar esta breve',
'icone_referencer_nouveau_site' => 'Referenciar un nuevu sitiu',
'icone_refuser_breve' => 'Refugar esta breve',
'icone_relancer_signataire' => 'Rellanzar el roblador',
'icone_retour' => 'Tornar',
'icone_retour_article' => 'Tornar a l\'art&iacute;culu',
'icone_suivi_forum' => 'Siguimientu del foru p&uacute;blicu: @nb_forums@&nbsp;contribuci&oacute;n(es)',
'icone_supprimer_cookie' => 'Desaniciar la cookie de correspondencia',
'icone_supprimer_groupe_mots' => 'Desaniciar esti grupu',
'icone_supprimer_rubrique' => 'Desaniciar esta estaya',
'icone_supprimer_signature' => 'Desaniciar esta robla',
'icone_valider_signature' => 'Validar esta robla',
'icone_voir_sites_references' => 'Ver los sitios referenciaos',
'icone_voir_tous_mots_cles' => 'Ver toles pallabres-clave',
'image_administrer_rubrique' => 'Puedes alministrar esta estaya',
'info_1_article' => '1 art&iacute;culu',
'info_1_breve' => '1 breve',
'info_1_site' => '1 sitiu web',
'info_activer_cookie' => 'Puedes activar una <b>cookie de correspondencia</b>, que va
 permitite que pases f&aacute;cilmente del sitiu p&uacute;blicu al sitiu privau.',
'info_activer_forum_public' => '<i>Pa activar los foros p&uacute;blicos, has d\'escoyer el tipu
 de moderaci&oacute;n por omisi&oacute;n:</i>',
'info_admin_gere_rubriques' => 'Esti alministrador xestiona les estayes siguientes:',
'info_admin_gere_toutes_rubriques' => 'Esti alministrador xestiona <b>toles estayes</b>.',
'info_admin_statuer_webmestre' => 'Donner &agrave; cet administrateur les droits de webmestre', # NEW
'info_admin_webmestre' => 'Cet administrateur est <b>webmestre</b>', # NEW
'info_administrateur' => 'Xesti&oacute;n',
'info_administrateur_1' => 'Xesti&oacute;n',
'info_administrateur_2' => 'de la web (<i>&uacute;salo con cuid&aacute;u</i>)',
'info_administrateur_site_01' => 'Si tas nel equipu de xesti&oacute;n,',
'info_administrateur_site_02' => 'pica n\'esti enllaz',
'info_administrateurs' => 'Alministradores',
'info_administrer_rubrique' => 'Puedes alministrar esta estaya',
'info_adresse' => 'a les se&ntilde;es:',
'info_adresse_email' => 'SE&Ntilde;ES D\'EMAIL:',
'info_adresse_url' => 'Direici&oacute;n (URL) del sitiu p&uacute;blicu',
'info_afficher_visites' => 'Amosar les visites pa:',
'info_affichier_visites_articles_plus_visites' => 'Amosar les visites pa <b>los art&iacute;culos m&aacute;s visitaos dende l\'entamu:</b>',
'info_aide_en_ligne' => 'Aida en llinia de SPIP',
'info_ajout_image' => 'Cuando amestes im&aacute;xenes como documentos axuntaos a un art&iacute;culu,
  SPIP puede crear por t&iacute;, autom&aacute;ticamente, vi&ntilde;etes (miniatures) de les
  im&aacute;xenes inxertaes. Esto permite por exemplu crear
  autom&aacute;ticamente una galer&iacute;a o un &aacute;lbum.',
'info_ajout_participant' => 'Amestose el siguiente participante:',
'info_ajouter_rubrique' => 'Amestar otra estaya pa alministrar:',
'info_annonce_nouveautes' => 'Anunciu de les noved&aacute;es',
'info_anterieur' => 'anterior',
'info_appliquer_choix_moderation' => 'Aplicar esta escoyeta pal llendamientu:',
'info_article' => 'art&iacute;culu',
'info_article_2' => 'art&iacute;culos',
'info_article_a_paraitre' => 'Los art&iacute;culos que apaecer&aacute;n en feches futures',
'info_articles_02' => 'art&iacute;culos',
'info_articles_2' => 'Art&iacute;culos',
'info_articles_auteur' => 'Los art&iacute;culos d\'esti autor',
'info_articles_lies_mot' => 'Los art&iacute;culos enllazaos con esta pallabra-clave',
'info_articles_trouves' => 'Art&iacute;culos alcontraos',
'info_articles_trouves_dans_texte' => 'Art&iacute;culos alcontraos (nel testu)',
'info_attente_validation' => 'Los tos art&iacute;culos esperando validaci&oacute;n',
'info_aujourdhui' => 'g&uuml;ei:',
'info_auteur_message' => 'AUTOR DEL MENSAXE:',
'info_auteurs' => 'Los autores',
'info_auteurs_par_tri' => 'Autores@partri@',
'info_auteurs_trouves' => 'Autores alcontr&aacute;os',
'info_authentification_externe' => 'Autentificaci&oacute;n esterna',
'info_avertissement' => 'Avisu',
'info_barre_outils' => 'cola so barra de ferramientes?',
'info_base_installee' => 'L\'armaz&oacute;n de la base de datos ta instalada.',
'info_base_restauration' => 'La base ta en procesu de restauraci&oacute;n.',
'info_bloquer' => 'bloquiar',
'info_breves' => '&iquest;Utiliza\'l to sitiu el sistema de breves?',
'info_breves_03' => 'breves',
'info_breves_liees_mot' => 'Les breves llig&aacute;es con esta pallabra-clave',
'info_breves_touvees' => 'Breves alcontr&aacute;es',
'info_breves_touvees_dans_texte' => 'Breves alcontr&aacute;es (nel testu)',
'info_changer_nom_groupe' => 'Cambear el nome d\'esti grupu:',
'info_chapeau' => 'Cabecera',
'info_chapeau_2' => 'Cabecera:',
'info_chemin_acces_1' => 'Opciones: <b>Cam&iacute;n d\'accesu na gu&iacute;a</b>',
'info_chemin_acces_2' => 'Agora debes configurar el cam&iacute;n d\'accesu a la informaci&oacute;n de la gu&iacute;a. Esta informaci&oacute;n ye indispensable pa lleer los perfiles d\'usuariu guard&aacute;os na gu&iacute;a.',
'info_chemin_acces_annuaire' => 'Opciones: <b>Cam&iacute;n d\'accesu na gu&iacute;a</b>',
'info_choix_base' => 'Tercera etapa:',
'info_classement_1' => '<sup>u</sup> en @liste@',
'info_classement_2' => '<sup>u</sup> en @liste@',
'info_code_acces' => '&iexcl;Nun escaezas los tos c&oacute;digos d\'accesu!',
'info_comment_lire_tableau' => 'C&oacute;mo lleer esti cuadru',
'info_compresseur_gzip' => '<b>Nota:</b> Recomi&eacute;ndase verificar de mano si l\'agospiador ya comprime autom&aacute;ticamente los scripts php&nbsp;; pa esto, puedes utilizar por exemplu el serviciu siguiente: @testgzip@',
'info_compresseur_texte' => 'Si el to sirvidor nun comprime autom&aacute;ticamente les p&aacute;xines html par unviales a los internautes, puedes tentar de forzar esta compresi&oacute;n pa amenorgar el pesu de les p&aacute;xines descarg&aacute;es. <b>Atenci&oacute;n</b>: esto puede ralentizar enforma dellos sirvidores.',
'info_compresseur_titre' => 'Ig&uuml;es y compresi&oacute;n',
'info_config_forums_prive' => 'Nel espaciu priv&aacute;u del sitiu, puedes activar dellos tipos de foros:',
'info_config_forums_prive_admin' => 'Un foru acut&aacute;u pa los alministradores del sitiu:',
'info_config_forums_prive_global' => 'Un foru global, abiertu pa tolos redactores:',
'info_config_forums_prive_objets' => 'Un foru pa cada art&iacute;culu, breve, sitiu referenci&aacute;u, etc.:',
'info_config_suivi' => 'Si estes se&ntilde;es corresponden a una llista de corr&eacute;u, pues indicar embaxo les se&ntilde;es nes que pueden apuntase los participantes nel sitiu. Estes se&ntilde;es puen ser una URL (por exemplu la p&aacute;xina d\'inscripci&oacute;n a la llista na Rede), o unes se&ntilde;es d\'email con un asuntu espec&iacute;ficu (por exemplu: <tt>@se&ntilde;es_llista@?subject=subscribe</tt>):',
'info_config_suivi_explication' => 'Puedes soscribite a la llista de corr&eacute;u d\'esti sitiu. D\'esti mou recibir&aacute;s per corr&eacute;u electr&oacute;nicu los anuncios d\'art&iacute;culos y de breves propuestos pa espublizar.',
'info_confirmer_passe' => 'Confirmar esta nueva contrase&ntilde;a:',
'info_conflit_edition_avis_non_sauvegarde' => 'Atenci&oacute;n, los campos siguientes camud&aacute;ronse n\'otra parte. Poro, les modificaciones dientro d\'esos campos nun se grabaron.',
'info_conflit_edition_differences' => 'Diferencies:',
'info_conflit_edition_version_enregistree' => 'La versi&oacute;n grabada:',
'info_conflit_edition_votre_version' => 'La to versi&oacute;n:',
'info_connexion_base' => 'Preba de conex&oacute;n a la base',
'info_connexion_base_donnee' => 'Conex&oacute;n cola to base de datos',
'info_connexion_ldap_ok' => 'La conex&oacute;n LDAP funcion&oacute;.</b><p> Puedes pasar a la etapa siguiente.</p>', # MODIF
'info_connexion_mysql' => 'La to conex&oacute;n SQL',
'info_connexion_ok' => 'La conex&oacute;n funcion&oacute;.',
'info_contact' => 'Contautu',
'info_contenu_articles' => 'Conten&iacute;u de los art&iacute;culos',
'info_creation_mots_cles' => 'Crear ya iguar les pallabres clave del sitiu',
'info_creation_paragraphe' => '(Pa crear p&aacute;rrafos, dexa ll&iacute;nies vac&iacute;es ente ellos.)',
'info_creation_rubrique' => 'Enantes que puedas escribir art&iacute;culos<br />debes crear polo menos una estaya.<br />',
'info_creation_tables' => 'Creaci&oacute;n de les tables de la base',
'info_creer_base' => '<b>Crear</b> una nueva base datos:',
'info_dans_groupe' => 'Nel grupu:',
'info_dans_rubrique' => 'Na estaya:',
'info_date_publication_anterieure' => 'Fecha de redaici&oacute;n anterior:',
'info_date_referencement' => 'FECHA DE REFERENCIACI&Oacute;N D\'ESTI SITIU:',
'info_delet_mots_cles' => 'Pedisti desaniciar la pallabra-clave
<b>@titre_mot@</b> (@type_mot@). Como esta pallabra ta enllazada
con <b>@texte_lie@</b> debes confirmar esta decisi&oacute;n:',
'info_derniere_etape' => '&iexcl;Ya finamos!',
'info_derniere_syndication' => 'La cabera sindicaci&oacute;n d\'esti sitiu efeutuose el',
'info_derniers_articles_publies' => 'Los caberos art&iacute;culos espublizaos en llinia',
'info_desactiver_forum_public' => 'Desactivar l\'usu de los foros publicos.
 Los foros p&uacute;blicos podr&aacute;n autorizase casu por casu
 pa los art&iacute;culos; pero tar&aacute;n torgaos pa les estayes, breves, etc.',
'info_desactiver_messagerie_personnelle' => 'Pues activar o desactivar la mensaxer&iacute;a personal nesti sitiu.',
'info_descriptif' => 'Descripci&oacute;n:',
'info_desinstaller_plugin' => 'desanicia los datos y desactiva el plugin',
'info_discussion_cours' => 'Discutinios en cursu',
'info_ecrire_article' => 'Enantes que puedas escribir art&iacute;culos, tienes que crear polo menos una estaya.',
'info_email_envoi' => 'Se&ntilde;es d\'email d\'unv&iacute;u (opcional)',
'info_email_envoi_txt' => 'Indica equ&iacute; les se&ntilde;es a utilizar pa unviar los emails (por omisi&oacute;n, usense les se&ntilde;es del destinatariu como se&ntilde;es d\'unv&iacute;u):',
'info_email_webmestre' => 'Se&ntilde;es d\'email del webmaster (opcional)',
'info_entrer_code_alphabet' => 'Enxerta\'l c&oacute;digu de l\'alfabetu a utilizar:',
'info_envoi_email_automatique' => 'Unv&iacute;u d\'e-mails autom&aacute;ticu',
'info_envoi_forum' => 'Unv&iacute;u de los foros a los autores de los art&iacute;culos',
'info_envoyer_maintenant' => 'Unviar agora',
'info_erreur_restauration' => 'Error na restauraci&oacute;n: archivu inesistente.',
'info_etape_suivante' => 'Pasar a la etapa siguiente',
'info_etape_suivante_1' => 'Puedes pasar a la etapa siguiente.',
'info_etape_suivante_2' => 'Puedes pasar a la etapa siguiente.',
'info_exportation_base' => 'esportaci&oacute;n de la base a @archive@',
'info_facilite_suivi_activite' => 'Col env&iacute;s de facilitar el siguimientu de l\'activid&aacute;
  editorial del sitiu, SPIP pue comunicar por e-mail, por exemplu
  a una llista de corr&eacute;u de redactores, l\'anunciu de les propuestes de
  publicaci&oacute;n y les validaciones d\'art&iacute;culos.',
'info_fichiers_authent' => 'Archivos d\'autentificaci&oacute;n &laquo;.htpasswd&raquo;',
'info_fonctionnement_forum' => 'Funcionamientu del foru:',
'info_forum_administrateur' => 'foru de los alministradores',
'info_forum_interne' => 'foru internu',
'info_forum_ouvert' => 'Nel espaciu priv&aacute;u del sitiu, hai un foru abiertu a tolos
  redactores rexistr&aacute;os. Equ&iacute; embaxo puedes activar un
  foru suplementariu, acut&aacute;u s&oacute;lo pa los alministradores.',
'info_forum_statistiques' => 'Estad&iacute;stiques de les visites',
'info_forums_abo_invites' => 'Esti sitiu tien foros pa abonaos; poro a los visiteurs se-yos encamienta que se rexistren nel sitiu p&uacute;blicu.',
'info_gauche_admin_effacer' => '<b>Esta p&aacute;xina nam&aacute;i ye accesible pa los responsables del sitiu.</b><p> Equ&iacute; ta l\'accesu a les diferentes funciones de mantenimientu t&eacute;unicu. Delles llancen un procesu d\'autentificaci&oacute;n espec&iacute;ficu, pal que fai falta tener accesu per FTP al sirvidor del sitiu Web.</p>', # MODIF
'info_gauche_admin_tech' => '<b>Esta p&aacute;xina nam&aacute;i ye accesible pa los responsables del sitiu.</b><p> Equ&iacute; ta l\'accesu a les diferentes
funciones de mantenimientu t&eacute;unicu. Delles llancen un procesu d\'autentificaci&oacute;n espec&iacute;ficu, pal que
fai falta tener accesu per FTP al sirvidor del sitiu Web.</p>', # MODIF
'info_gauche_admin_vider' => '<b>Esta p&aacute;xina nam&aacute;i ye accesible pa los responsables del sitiu.</b><p> Equ&iacute; ta l\'accesu a les diferentes
funciones de mantenimientu t&eacute;unicu. Delles llancen un procesu d\'autentificaci&oacute;n espec&iacute;ficu, pal que
fai falta tener accesu per FTP al sirvidor del sitiu Web.</p>', # MODIF
'info_gauche_auteurs' => 'Equ&iacute; s\'alcuentren tolos autores del sitiu.
 El so estatutu vien indic&aacute;u pola color de l\'iconu (alministrador = verde; redactor = mariellu).',
'info_gauche_auteurs_exterieurs' => 'Los autores esternos, ensin accesu al sitiu, vienen indicaos con un iconu azul;
  los autores esborr&aacute;os con un calderu de basoria.',
'info_gauche_messagerie' => 'La mensaxer&iacute;a permite mandase mensaxes ente redactores, conservar recordatorioss (pa usu personal) o amosar anuncies na p&aacute;xina principal de l\'espaciu priv&aacute;u (si yes alministrador).',
'info_gauche_numero_auteur' => 'AUTOR N&Uacute;MBERU',
'info_gauche_numero_breve' => 'BREVE N&Uacute;MBERU',
'info_gauche_statistiques_referers' => 'Esta p&aacute;xina presenta la llista de los <i>referers</i>, que son sitios que contienen enllaces que apunten pa esti mesmu sitiu, nam&aacute;i d\'ayeri y de g&uuml;ei; esta llista ponse a cero cada 24 hores.',
'info_gauche_suivi_forum' => 'La p&aacute;xina de <i>siguimientu de los foros</i> ye una ferramienta de xesti&oacute;n del sitiu Web (y non un espaciu pal discutiniu o la redaici&oacute;n). Amuesa toles contribuciones del foru p&uacute;blicu d\'esti art&iacute;culu y te permite remanar eses contribuciones.',
'info_gauche_suivi_forum_2' => 'La p&aacute;xina de <i>siguimientu de los foros</i> ye una ferramienta de xesti&oacute;n del sitiu Web (y non un espaciu pal discutiniu o la redaici&oacute;n). Amuesa toles contribuciones de los foros del sitiu, lo mesmo de la parte p&uacute;blica que del espaciu priv&aacute;u y te permite remanar eses contribuciones.',
'info_gauche_visiteurs_enregistres' => 'Equ&iacute; alcontrar&aacute;s los visitantes rexistraes
 nel espaciu p&uacute;blicu del sitiu (foros pa abonaos).',
'info_generation_miniatures_images' => 'Xeneraci&oacute;n d\'imaxes amenorg&aacute;es',
'info_gerer_trad' => '&iquest;Xestionar los enllaces de traducci&oacute;n?',
'info_groupe_important' => 'Grupu importante',
'info_hebergeur_desactiver_envoi_email' => 'Dellos agospiamientos encaboxen l\'unv&iacute;u autom&aacute;ticu de
  correos dende los sos sirvidores. Nesti casu, les siguientes
  carauter&iacute;stiques de SPIP nun funcionar&aacute;n.',
'info_hier' => 'ayeri:',
'info_historique' => 'Revisiones:',
'info_historique_activer' => 'Activar el siguimientu de les revisiones',
'info_historique_affiche' => 'Amosar esta versi&oacute;n',
'info_historique_comparaison' => 'comparanza',
'info_historique_desactiver' => 'Desactivar el siguimientu de les revisiones',
'info_historique_lien' => 'Amosar l\'hist&oacute;ricu de los camb&eacute;os',
'info_historique_texte' => 'El siguimientu de les revisiones permite conservar un hist&oacute;ricu de toles modificaciones amestaes al conten&iacute;u d\'un art&iacute;culu, y amosar les diferencies ente les versiones sucesives.',
'info_historique_titre' => 'Siguimientu de les revisiones',
'info_identification_publique' => 'La to identid&aacute; p&uacute;blica...',
'info_image_process' => 'Has d\'escoyer el meyor m&eacute;todu de fabricaci&oacute;n de les vi&ntilde;etes calcando enriba de la imaxe correspondiente.',
'info_image_process2' => '<b>N.B.</b> <i>Si nun apaez imaxe dala, el sirvidor que agospia el to sitiu nun ta configur&aacute;u pa mandase d\'estes ferramientes. Si qui&eacute;s utilizar estes funciones, contauta col responsable t&eacute;unicu y pide-y les estensiones &laquo;GD&raquo; o &laquo;Imagick&raquo;.</i>',
'info_images_auto' => 'Imaxes calcul&aacute;es autom&aacute;ticamente',
'info_informations_personnelles' => 'Informaci&oacute;n personal',
'info_inscription_automatique' => 'Inscripci&oacute;n autom&aacute;tica de redactores nuevos',
'info_jeu_caractere' => 'Xuegu de carauteres del sitiu',
'info_jours' => 'd&iacute;es',
'info_laisser_champs_vides' => 'dexar estos campos vac&iacute;os)',
'info_langues' => 'Idiomes del sitiu',
'info_ldap_ok' => 'L\'autentificaci&oacute;n LDAP ta instalada.',
'info_lien_hypertexte' => 'Enllace d\'hipertestu:',
'info_liens_syndiques_1' => 'enllaces sindicaos',
'info_liens_syndiques_2' => 'tan esperando validaci&oacute;n.',
'info_liens_syndiques_3' => 'foros',
'info_liens_syndiques_4' => 'tan',
'info_liens_syndiques_5' => 'foru',
'info_liens_syndiques_6' => 'ta',
'info_liens_syndiques_7' => 'esperando pola validaci&oacute;n',
'info_liste_redacteurs_connectes' => 'Llista de los redactores conect&aacute;os',
'info_login_existant' => 'Esti nome ya esiste.',
'info_login_trop_court' => 'El nome ye mui curtiu.',
'info_logos' => 'Los logos',
'info_maximum' => 'm&aacute;simu:',
'info_meme_rubrique' => 'Na mesma estaya',
'info_message' => 'Mensaxe de',
'info_message_efface' => 'MENSAXE DESANICI&Aacute;U',
'info_message_en_redaction' => 'Los tos mensaxes en cursu de redacci&oacute;n',
'info_message_technique' => 'Mensaxe t&eacute;unicu:',
'info_messagerie_interne' => 'Mensaxer&iacute;a interna',
'info_mise_a_niveau_base' => 'axuste de la base de datos SQL',
'info_mise_a_niveau_base_2' => '{{&iexcl;Atenci&oacute;n!}} Instalasti una versi&oacute;n de los
  archivos de SPIP {anterior} a la que s\'alcontraba
  enantes nesti sitiu: la base de datos puede tar
  perdida y el sitiu ya nun funcionar&aacute;.<br />{{Reinstala los
  archivos de SPIP.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Mou de funcionamientu por omisi&oacute;n de los foros p&uacute;blicos',
'info_modifier_auteur' => 'Modificar l\'autor:',
'info_modifier_breve' => 'Modificar la breve:',
'info_modifier_mot' => 'Modificar la pallabra-clave:',
'info_modifier_rubrique' => 'Modificar la estaya:',
'info_modifier_titre' => 'Modificar: @titre@',
'info_mon_site_spip' => 'El mio sitiu SPIP',
'info_mot_sans_groupe' => '(Pallabres ensin grupu...)',
'info_moteur_recherche' => 'Motor de gueta integr&aacute;u',
'info_mots_cles' => 'Les pallabres-clave',
'info_mots_cles_association' => 'Les pallabres-clave d\'esti grupu puen asociase:',
'info_moyenne' => 'media:',
'info_multi_articles' => '&iquest;Activar el men&uacute; de lling&uuml;es pa los art&iacute;culos?',
'info_multi_cet_article' => 'Llingua d\'esti art&iacute;culu:',
'info_multi_langues_choisies' => 'Seleiciona de sigu&iacute;o les lling&uuml;es disponibles pa los redactores del sitiu Web.
  Les lling&uuml;es que ya tan us&aacute;ndose nel sitiu (amosaes en primer llugar) nun puen desactivase.',
'info_multi_rubriques' => '&iquest;Activar el men&uacute; de lling&uuml;es pa les estayes?',
'info_multi_secteurs' => '... &iquest;s&oacute;lamente pa les estayes allug&aacute;es na raiz?',
'info_nom' => 'Nome',
'info_nom_destinataire' => 'Nome del destinatariu',
'info_nom_site' => 'Nome del to sitiu',
'info_nom_site_2' => '<b>Nome del sitiu</b> [Obligatoriu]',
'info_nombre_articles' => '@nb_articles@ art&iacute;culos,',
'info_nombre_breves' => '@nb_breves@ noticies breves,',
'info_nombre_partcipants' => 'PARTICIPANTES NEL DISCUTINIU:',
'info_nombre_rubriques' => '@nb_rubriques@ estayes,',
'info_nombre_sites' => '@nb_sites@ sitios web,',
'info_non_deplacer' => 'Nun desplazar...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pue unviar, regularmente, l\'anunciu de les caberes novedaes del sitiu
  (art&iacute;culos y breves espublizaos apocay&aacute;).',
'info_non_envoi_liste_nouveautes' => 'Nun mandar la llista de les noved&aacute;es',
'info_non_modifiable' => 'nun pue camudase',
'info_non_suppression_mot_cle' => 'nun quiero desaniciar esta pallabra-clave.',
'info_notes' => 'Notes',
'info_nouveaux_message' => 'Mensaxes nuevos',
'info_nouvel_article' => 'Art&iacute;culu nuevu',
'info_nouvelle_traduction' => 'Traducci&oacute;n nueva:',
'info_numero_article' => 'ART&Iacute;CULU N&Uacute;MBERU:',
'info_obligatoire_02' => '[Obligatorio]',
'info_option_accepter_visiteurs' => 'Aceptar la inscripci&oacute;n de visitantes del sitiu p&uacute;blicu',
'info_option_email' => 'Cuando un visitante del sitiu unv&iacute;a un mensaxe nuevu al foru vencey&aacute;u a un art&iacute;culu, puede avisase a los o les autores del mesmu por e-mail. Escoyer pa cada tipu de foru si va emplegase esta opci&oacute;n.',
'info_option_faire_suivre' => 'Unvia-yos copia de los mensaxes de los foros a los autores de los art&iacute;culos',
'info_option_ne_pas_accepter_visiteurs' => 'Refugar la inscripci&oacute;n de los visitantes',
'info_option_ne_pas_faire_suivre' => 'Nun mandar copia de los mensaxes de los foros',
'info_options_avancees' => 'OPCIONES AVANZ&Aacute;ES',
'info_ortho_activer' => 'Activar el correutor ortogr&aacute;ficu',
'info_ortho_desactiver' => 'Desactivar el correutor ortogr&aacute;ficu',
'info_ou' => 'o...',
'info_oui_suppression_mot_cle' => 'quiero desaniciar definitivamente esta pallabra-clave.',
'info_page_interdite' => 'P&aacute;xina torgada',
'info_par_nom' => 'pol nome',
'info_par_nombre_article' => 'pol n&uacute;mberu d\'art&iacute;culos',
'info_par_statut' => 'pol cargu',
'info_par_tri' => '\'(por @tri@)\'',
'info_pas_de_forum' => 'ensin foru',
'info_passe_trop_court' => 'La contrase&ntilde;a ye mui curtia.',
'info_passes_identiques' => 'Les dos contrase&ntilde;es nun concasen.',
'info_pense_bete_ancien' => 'Recordatorios antiguos', # MODIF
'info_plus_cinq_car' => 'm&aacute;s de 5 carauteres',
'info_plus_cinq_car_2' => '(M&aacute;s de 5 carauteres)',
'info_plus_trois_car' => '(M&aacute;s de 3 carauteres)',
'info_popularite' => 'popularid&aacute;:&nbsp;@popularite@; visites:&nbsp;@visites@',
'info_popularite_2' => 'popularid&aacute; del sitiu:',
'info_popularite_3' => 'popularid&aacute;:&nbsp;@popularite@; visites:&nbsp;@visites@',
'info_popularite_4' => 'popularid&aacute;:&nbsp;@popularite@; visites&nbsp;:&nbsp;@visites@',
'info_post_scriptum' => 'Post Scr&iacute;ptum',
'info_post_scriptum_2' => 'Post Scr&iacute;ptum:',
'info_pour' => 'pa',
'info_preview_admin' => 'Nam&aacute;i los alministradores puen previsualizar el sitiu',
'info_preview_comite' => 'Tolos redactores puen previsualizar el sitiu',
'info_preview_desactive' => 'La previsualizaci&oacute;n ta desactivada dafechu',
'info_preview_texte' => 'Ye posible previsualizar el sitiu como si tolos art&iacute;culos y les breves (que tengan polo menos l\'estatutu &laquo;propuestu&raquo;) tuvieren espublizaos. &iquest;Esta posibilid&aacute; tien que tar abierta pa los alministradores nam&aacute;i, pa tolos redactores, o pa naide?',
'info_principaux_correspondants' => 'Principales intercamb&eacute;os de mensaxes',
'info_procedez_par_etape' => 'sigue pasu ente pasu',
'info_procedure_maj_version' => 'hai que llanzar el procesu d\'actualizaci&oacute;n a la fin d\'adautar
 la base de datos a la nueva versi&oacute;n de SPIP.',
'info_proxy_ok' => 'Preba del proxy superada.',
'info_ps' => 'P.-S.',
'info_publier' => 'espublizar',
'info_publies' => 'Los tos art&iacute;culos espubliz&aacute;os en llinia',
'info_question_accepter_visiteurs' => 'Si les cadarmes d\'esti sitiu prev&eacute;n el rexistru de visitantes ensin accesu a l\'espaciu priv&aacute;u, has d\'activar la opci&oacute;n d\'embaxo:',
'info_question_activer_compactage_css' => '&iquest;Quies activar la compautaci&oacute;n de les fueyes d\'estilu (CSS)?',
'info_question_activer_compactage_js' => '&iquest;Quies activar la compautaci&oacute;n de los scripts (JavaScript)?',
'info_question_activer_compresseur' => '&iquest;Quies activar la compresi&oacute;n del tr&aacute;ficu HTTP?',
'info_question_gerer_statistiques' => '&iquest;El sitiu tien que xestionar les estad&iacute;stiques de les visites?',
'info_question_inscription_nouveaux_redacteurs' => '&iquest;Aceutes les inscripciones de nuevos redactores dende\'l
  sitiu p&uacute;blicu? Si aceutes, los visitantes podr&aacute;n inscribise
  dende un formulariu automatiz&aacute;u y tendr&aacute;n accesu a l\'espaciu priv&aacute;u pa
  proponer art&iacute;culos propios. <blockquote><i>Tres de la fase d\'inscripci&oacute;n,
  los usuarios reciben un corr&eacute;u electr&oacute;nicu autom&aacute;ticu
  que-yos da los c&oacute;digos d\'accesu al sitiu priv&aacute;u. Dellos
  agospiadores desactiven l\'unv&iacute;u d\'e-mails dende los sos
  sirvidores: nesti casu, la inscripci&oacute;n autom&aacute;tica ye
  imposible.</i></blockquote>',
'info_question_mots_cles' => '&iquest;Quies utilizar les pallabres-clave nesti sitiu?',
'info_question_proposer_site' => '&iquest;Qui&eacute;n pue proponer sitios referenciaos?',
'info_question_utilisation_moteur_recherche' => '&iquest;Quies utilizar el motor de restolar integr&aacute;u con SPIP?
 (desactivalu acelera el funcionamientu del sistema.)',
'info_question_vignettes_referer' => 'Cuando consultes les estad&iacute;stiques, pues amosar miniatures de los sitios d\'orixe de les visites',
'info_question_vignettes_referer_non' => 'Nun amosar les captures de los sitios d\'orixe de les visites',
'info_question_vignettes_referer_oui' => 'Amosar captures de los sitios d\'orixe de les visites',
'info_question_visiteur_ajout_document_forum' => 'Si qui&eacute;s autorizar que los visitantes amesten documentos (im&aacute;xenes, sones...) nos sos mensaxes del foru, indica embaxo la llista d\'estensiones de documentu permit&iacute;es nos foros (p. ex: gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'Si qui&eacute;s autorizar tolos tipos de documentu que SPIP considera fiables, pon un asteriscu. Pa nun autorizar na, d&eacute;xalo en blancu,',
'info_qui_attribue_mot_cle' => 'Les pallabres d\'esti grupu puen conse&ntilde;ase por:',
'info_racine_site' => 'Raiz del sitiu',
'info_recharger_page' => 'Ties que recargar esta p&aacute;xina nunos instantes.',
'info_recherche_auteur_a_affiner' => 'Hai resultaos asgaya pa "@cherche_auteur@", apurre m&aacute;s criterios a la gueta.',
'info_recherche_auteur_ok' => 'Atop&aacute;ronse dellos autores pa "@cherche_auteur@":',
'info_recherche_auteur_zero' => 'Nun hai resultaos pa &laquo;@cherche_auteur@&raquo;.',
'info_recommencer' => 'Vuelve a entamar',
'info_redacteur_1' => 'Redactor',
'info_redacteur_2' => 'con accesu a l\'espaciu priv&aacute;u (<i>encamentao</i>)',
'info_redacteurs' => 'Redactores',
'info_redaction_en_cours' => 'EN CURSU DE REDAICI&Oacute;N',
'info_redirection' => 'Redireici&oacute;n',
'info_referencer_doc_distant' => 'Referenciar un documentu de Internet:',
'info_refuses' => 'Los tos art&iacute;culos refug&aacute;os',
'info_reglage_ldap' => 'Opciones: <b>Axuste de la importaci&oacute;n LDAP</b>',
'info_renvoi_article' => '<b>Redireici&oacute;n.</b> Esti art&iacute;culu reunv&iacute;a a la p&aacute;xina:',
'info_reserve_admin' => 'Nam&aacute;i los alministradores puen camudar estes se&ntilde;es.',
'info_restauration_sauvegarde' => 'Restauraci&oacute;n de la copia de segurid&aacute; @archive@',
'info_restauration_sauvegarde_insert' => 'Amestura de @archive@ na base',
'info_restreindre_rubrique' => 'Llendar la xesti&oacute;n a la estaya:',
'info_resultat_recherche' => 'Resultaos de la gueta:',
'info_rubriques' => 'Estayes',
'info_rubriques_02' => 'estayes',
'info_rubriques_liees_mot' => 'Les estayes llig&aacute;es con esta pallabra-clave',
'info_rubriques_trouvees' => 'Estayes alcontr&aacute;es',
'info_rubriques_trouvees_dans_texte' => 'Estayes alcontr&aacute;es (nel testu)',
'info_sans_titre' => 'Ensin t&iacute;tulu',
'info_sauvegarde' => 'Copia de segurid&aacute;',
'info_sauvegarde_articles' => 'Facer copia de segurid&aacute; de los art&iacute;culos',
'info_sauvegarde_articles_sites_ref' => 'Facer copia de segurid&aacute; de los art&iacute;culos de sitios referenciaos',
'info_sauvegarde_auteurs' => 'Facer copia de segurid&aacute; de los autores',
'info_sauvegarde_breves' => 'Facer copia de segurid&aacute; de les breves',
'info_sauvegarde_documents' => 'Facer copia de segurid&aacute; de los documentos',
'info_sauvegarde_echouee' => 'Si fall&oacute; la copia de segurid&aacute; (&laquo;Maximum execution time exceeded&raquo;),',
'info_sauvegarde_forums' => 'Facer copia de segurid&aacute; de los foros',
'info_sauvegarde_groupe_mots' => 'Facer copia de segurid&aacute; de los grupos de pallabres',
'info_sauvegarde_messages' => 'Facer copia de segurid&aacute; de los mensaxes',
'info_sauvegarde_mots_cles' => 'Facer copia de segurid&aacute; de les pallabres-clave',
'info_sauvegarde_petitions' => 'Facer copia de segurid&aacute; de les solicitudes',
'info_sauvegarde_refers' => 'Facer copia de segurid&aacute; de los referidores',
'info_sauvegarde_reussi_01' => 'Copia de segurid&aacute; correuta.',
'info_sauvegarde_reussi_02' => 'La base de datos guardose en @archive@. Puedes',
'info_sauvegarde_reussi_03' => 'tornar pa la xesti&oacute;n',
'info_sauvegarde_reussi_04' => 'del sitiu web.',
'info_sauvegarde_rubrique_reussi' => 'Les tables de la estaya @titre@ guard&aacute;ronse en @archive@. Puedes',
'info_sauvegarde_rubriques' => 'Facer copia de segurid&aacute; de les estayes',
'info_sauvegarde_signatures' => 'Facer copia de segurid&aacute; de les robles de solicitudes',
'info_sauvegarde_sites_references' => 'Facer copia de segurid&aacute; de los sitios referenciaos',
'info_sauvegarde_type_documents' => 'Facer copia de segurid&aacute; de los tipos de documentu',
'info_sauvegarde_visites' => 'Facer copia de segurid&aacute; de les visites',
'info_selection_chemin_acces' => '<b>Seleiciona</b> de sigu&iacute;o el cam&iacute;n d\'accesu a la gu&iacute;a:',
'info_selection_un_seul_mot_cle' => 'Nun se pue seleicionar m&aacute;s que <b>una sola pallabra-clave</b> a la vez nesti grupu.',
'info_signatures' => 'robles',
'info_site' => 'Sitiu',
'info_site_2' => 'sitiu:',
'info_site_min' => 'sitiu Web',
'info_site_propose' => 'Sitiu propuestu el:',
'info_site_reference_2' => 'Sitiu referenciau',
'info_site_syndique' => 'Esti sitiu ta sindic&aacute;u...',
'info_site_valider' => 'Sitios a validar',
'info_site_web' => 'SITIU WEB:',
'info_sites' => 'sitios',
'info_sites_lies_mot' => 'Los sitios referenciaos enllazaos con esta pallabra-clave',
'info_sites_proxy' => 'Utilizar un proxy',
'info_sites_refuses' => 'Los sitios refugaos',
'info_sites_trouves' => 'Sitios alcontraos',
'info_sites_trouves_dans_texte' => 'Sitios alcontraos (nel testu)',
'info_sous_titre' => 'Subt&iacute;tulu:',
'info_statut_administrateur' => 'Alministrador',
'info_statut_auteur' => 'Estatutu d\'esti autor:',
'info_statut_auteur_a_confirmer' => 'Inscripci&oacute;n por confirmar',
'info_statut_auteur_autre' => 'Otru estatutu:',
'info_statut_efface' => 'Esborr&aacute;u',
'info_statut_redacteur' => 'Redactor',
'info_statut_site_1' => 'Esti sitiu ta:',
'info_statut_site_2' => 'Espubliz&aacute;u',
'info_statut_site_3' => 'Propuestu',
'info_statut_site_4' => 'Na basoria',
'info_statut_utilisateurs_1' => 'Estatutu por omisi&oacute;n de los usuarios importaos',
'info_statut_utilisateurs_2' => 'Escueye l\'estatutu que se-yos da a les persones presentes na gu&iacute;a LDAP cuando se conecten la primera vegada. Llu&eacute;u podr&aacute;s camudar esti valor pa ca&uacute;n de los autores casu per casu.',
'info_suivi_activite' => 'Siguimientu de l\'activid&aacute; editorial',
'info_supprimer_mot' => 'desaniciar&nbsp;esta&nbsp;pallabra',
'info_surtitre' => 'Antet&iacute;tulu:',
'info_syndication_integrale_1' => 'Esti sitiu ufre archivos de sindicaci&oacute;n (ver &laquo;<a href="@url@">@titre@</a>&raquo;).',
'info_syndication_integrale_2' => '&iquest;Quies tresmitir los art&iacute;culos ensembre, o nun esparder n&aacute;s que un resume con dellos cientos de carauteres?',
'info_table_prefix' => 'Pues cambear el prefixu del nome de les tables de datos (esto ye necesario dafechu si se quier instalar dellos sitios na mesma base de datos). Esti prefixu escr&iacute;bese en lletres min&uacute;scules, ensin acentos, y ensin espacios.',
'info_taille_maximale_images' => 'SPIP va comprebar el tama&ntilde;u m&aacute;simu de les imaxes que pue remanar (en millones de pixels).<br /> Les imaxes m&aacute;s grandes nun van reducise.',
'info_taille_maximale_vignette' => 'Tama&ntilde;u m&aacute;simu de les vi&ntilde;etes xener&aacute;es pol sistema:',
'info_terminer_installation' => 'Agora pues finar el procesu d\'instalaci&oacute;n est&aacute;ndar.',
'info_texte' => 'Testu',
'info_texte_explicatif' => 'Testu explicativu',
'info_texte_long' => '(el testu ye llargu: poro apaez en delles partes que volver&aacute;n a amestase tres de la validaci&oacute;n.)',
'info_texte_message' => 'Testu del to mensaxe:',
'info_texte_message_02' => 'Testu del mensaxe',
'info_titre' => 'T&iacute;tulu:',
'info_titre_mot_cle' => 'Nome o t&iacute;tulu de la pallabra clave',
'info_total' => 'total:',
'info_tous_articles_en_redaction' => 'Tolos art&iacute;culos en cursu de redaici&oacute;n',
'info_tous_articles_presents' => 'Tolos art&iacute;culos espublizaos nesta estaya',
'info_tous_articles_refuses' => 'Tous les articles refus&eacute;s', # NEW
'info_tous_les' => 'tolos:',
'info_tous_redacteurs' => 'Anuncios pa tolos redactores',
'info_tout_site' => 'Tou el sitiu',
'info_tout_site2' => 'L\'art&iacute;culu nun ta traduc&iacute;u a esta llingua.',
'info_tout_site3' => 'L\'art&iacute;culu ta traduc&iacute;u a esta llingua, pero despu&eacute;s amest&aacute;ronse modificaciones a l\'art&iacute;culu de referencia. La traducci&oacute;n tien que ponese al d&iacute;a.',
'info_tout_site4' => 'L\'art&iacute;culu ta traduc&iacute;u a esta llingua, y la traducci&oacute;n ta actualizada.',
'info_tout_site5' => 'Art&iacute;culu orixinal.',
'info_tout_site6' => '<b>Atenci&oacute;n&nbsp;:</b> s&oacute;lo se amuesen los art&iacute;culos orixinales.
Les traducciones asociense col orixinal,
con una color que indica el est&aacute;u:',
'info_travail_colaboratif' => 'Trabayu en comu&ntilde;a nos art&iacute;culos',
'info_un_article' => 'un art&iacute;culu,',
'info_un_mot' => 'Una sola pallabra a la vez',
'info_un_site' => 'un sitiu web,',
'info_une_breve' => 'una breve,',
'info_une_rubrique' => 'una estaya,',
'info_une_rubrique_02' => '1 estaya',
'info_url' => 'URL:',
'info_url_site' => 'URL del sitiu:',
'info_urlref' => 'Enllace d\'hipertestu:',
'info_utilisation_spip' => 'Agora puedes entamar a utilizar el sistema d\'espublizamientu asist&iacute;u...',
'info_visites_par_mois' => 'Amosar por meses:',
'info_visites_plus_populaires' => 'Amosar les visites de <b>los art&iacute;culos m&aacute;s populares</b> y de <b>los caberos art&iacute;culos espublizaos:</b>',
'info_visiteur_1' => 'Visitante',
'info_visiteur_2' => 'del sitiu p&uacute;blicu',
'info_visiteurs' => 'Visitantes',
'info_visiteurs_02' => 'Visitantes del sitiu p&uacute;blicu',
'install_adresse_base_hebergeur' => 'Direici&oacute;n de la base datos asitiada pol agospiador web',
'install_base_ok' => 'Reconoci&oacute;se la base @base@',
'install_echec_annonce' => 'La instalaci&oacute;n probablemente va fallar, o va producir un sitiu que nun funcione...',
'install_extension_mbstring' => 'SPIP nun funciona con:',
'install_extension_php_obligatoire' => 'SPIP esixe la estensi&oacute;n php:',
'install_login_base_hebergeur' => 'Login de conex&oacute;n conse&ntilde;&aacute;u pol agospiador',
'install_nom_base_hebergeur' => 'Nome de la base conse&ntilde;&aacute;u pol agospiador:',
'install_pas_table' => 'La base nun tien tables actualmente',
'install_pass_base_hebergeur' => 'Contrase&ntilde;a de conex&oacute;n conse&ntilde;ada pol agospiador',
'install_php_version' => 'PHP versi&oacute;n @version@ nun ye suficiente (minimo= @minimum@)',
'install_select_langue' => 'Escueye una ll&iacute;ngua y calca nel bot&oacute;n &laquo;siguiente&raquo; pa llanzar el procesu d\'instalaci&oacute;n.',
'install_select_type_db' => 'Indicar el tipu de base de datos:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL', # NEW
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Sirvidor de base de datos conse&ntilde;&aacute;u pol agospiador web',
'install_table_prefix_hebergeur' => 'Prefixu de tabla conse&ntilde;&aacute;u pol agospiamientu:',
'install_tables_base' => 'Tables de la base',
'install_types_db_connus' => 'SPIP sabe utilizar <b>MySQL</b> (la m&aacute;s estendida), <b>PostgreSQL</b> y <b>SQLite</b>.',
'install_types_db_connus_avertissement' => 'Atenci&oacute;n: hai dellos plugins que nun funcionen m&aacute;s que con MySQL',
'intem_redacteur' => 'redactor',
'intitule_licence' => 'Llicencia',
'item_accepter_inscriptions' => 'Aceptar les inscripciones',
'item_activer_forum_administrateur' => 'Activar el foru de los alministradores',
'item_activer_messages_avertissement' => 'Activar los mensaxes d\'avisu',
'item_administrateur_2' => 'alministrador',
'item_afficher_calendrier' => 'Amosar na axenda',
'item_ajout_mots_cles' => 'Autorizar l\'amestura de pallabres-clave nos foros',
'item_autoriser_documents_joints' => 'Autorizar los documentos axuntos nos art&iacute;culos',
'item_autoriser_documents_joints_rubriques' => 'Autorizar los documentos nes estayes',
'item_autoriser_selectionner_date_en_ligne' => 'Permitir el camb&eacute;u de fecha de los documentos',
'item_autoriser_syndication_integrale' => 'Difundir los art&iacute;culos completos en los archivos de sindicaci&oacute;n',
'item_bloquer_liens_syndiques' => 'Torgar los enllaces sindicaos pa validaci&oacute;n',
'item_breve_refusee' => 'NON - Breve refugada',
'item_breve_validee' => 'SI - Breve validada',
'item_choix_administrateurs' => 'los alministradores',
'item_choix_generation_miniature' => 'Xenerar autom&aacute;ticamente les im&aacute;xenes amenorg&aacute;es.',
'item_choix_non_generation_miniature' => 'Nun xenerar im&aacute;xenes amenorg&aacute;es.',
'item_choix_redacteurs' => 'los redactores',
'item_choix_visiteurs' => 'los visitantes del sitiu p&uacute;blicu',
'item_compresseur' => 'Activar la compresi&oacute;n',
'item_config_forums_prive_global' => 'Activar el foru de los redactores',
'item_config_forums_prive_objets' => 'Activar estos foros',
'item_creer_fichiers_authent' => 'Crear los archivos .htpasswd',
'item_desactiver_forum_administrateur' => 'Desactivar el foru de los alministradores',
'item_gerer_annuaire_site_web' => 'Xestionar una llista de sitios Web',
'item_gerer_statistiques' => 'Xestionar les estad&iacute;stiques',
'item_limiter_recherche' => 'Llendar la gueta a les informaciones conten&iacute;es nesti sitiu',
'item_login' => 'Login',
'item_messagerie_agenda' => 'Activar la mensaxer&iacute;a y l’axenda',
'item_mots_cles_association_articles' => 'a los art&iacute;culos',
'item_mots_cles_association_breves' => 'a les breves',
'item_mots_cles_association_rubriques' => 'a les estayes',
'item_mots_cles_association_sites' => 'a los sitios referenciaos o sindicaos.',
'item_non' => 'Non',
'item_non_accepter_inscriptions' => 'Nun aceutar les inscripciones',
'item_non_activer_messages_avertissement' => 'Ensin mensaxes d\'avisu',
'item_non_afficher_calendrier' => 'Nun amosar nel calendariu',
'item_non_ajout_mots_cles' => 'Torgar l\'usu de les pallabres-clave nos foros',
'item_non_autoriser_documents_joints' => 'Nun autorizar los documentos nos art&iacute;culos',
'item_non_autoriser_documents_joints_rubriques' => 'Nun autorizar los documentos nes estayes',
'item_non_autoriser_selectionner_date_en_ligne' => 'La fecha de los documentos ye la de puesta n\'esti sitiu',
'item_non_autoriser_syndication_integrale' => 'Nun esparder m&aacute;s que un resume',
'item_non_bloquer_liens_syndiques' => 'Nun bloquiar los enllaces apaecidos na sindicaci&oacute;n',
'item_non_compresseur' => 'Desactivar la compresi&oacute;n',
'item_non_config_forums_prive_global' => 'Desactivar el foru de los redactores',
'item_non_config_forums_prive_objets' => 'Desactivar estos foros',
'item_non_creer_fichiers_authent' => 'Nun crear estos archivos',
'item_non_gerer_annuaire_site_web' => 'Desactivar l\'anuariu de sitios Web',
'item_non_gerer_statistiques' => 'Nun xestionar les estad&iacute;stiques',
'item_non_limiter_recherche' => 'Estender la gueta al conten&iacute;u de los sitios referenciaos',
'item_non_messagerie_agenda' => 'Desactivar la mensaxeria y l’axenda',
'item_non_publier_articles' => 'Nun espublizar los art&iacute;culos enantes de la fecha d\'espublizamientu conse&ntilde;ada.',
'item_non_utiliser_breves' => 'Nun utilizar les breves',
'item_non_utiliser_config_groupe_mots_cles' => 'Nun utilizar la configuraci&oacute;n avanzada de los grupos de pallabres-clave',
'item_non_utiliser_moteur_recherche' => 'Nun utilizar el motor',
'item_non_utiliser_mots_cles' => 'Nun utilizar les pallabres-clave',
'item_non_utiliser_syndication' => 'Nun utilizar la sindicaci&oacute;n autom&aacute;tica',
'item_nouvel_auteur' => 'Autor nuevu',
'item_nouvelle_breve' => 'Breve nueva',
'item_nouvelle_rubrique' => 'Estaya nueva',
'item_oui' => 'S&iacute;',
'item_publier_articles' => 'Espublizar los art&iacute;culos, cualquiera que sea la fecha d\'espublizamientu.',
'item_reponse_article' => 'Respuesta a l\'art&iacute;culu',
'item_utiliser_breves' => 'Utilizar les breves',
'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuraci&oacute;n avanzada de los grupos de pallabres-clave',
'item_utiliser_moteur_recherche' => 'Utilizar el motor de gueta',
'item_utiliser_mots_cles' => 'Utilizar les pallabres-clave',
'item_utiliser_syndication' => 'Utilizar la sindicaci&oacute;n autom&aacute;tica',
'item_visiteur' => 'visitante',

// J
'jour_non_connu_nc' => 'n.c.',

// L
'ldap_correspondance' => 'herencia del campu @champ@',
'ldap_correspondance_1' => 'Herencia de campos LDAP',
'ldap_correspondance_2' => 'Pa ca&uacute;n de los campos SPIP siguientes, conse&ntilde;ar el nome del campu LDAP correspondiente. Dexar balero pa nun llenalu, separtar con espacios o comes pa tentar dellos campos LDAP.',
'lien_ajout_destinataire' => 'Amestar esti destinatariu',
'lien_ajouter_auteur' => 'Amestar esti autor',
'lien_ajouter_participant' => 'Amestar un participante',
'lien_email' => 'email',
'lien_forum_public' => 'Xestionar el foru p&uacute;blicu d\'esti art&iacute;culu',
'lien_mise_a_jour_syndication' => 'Actualizar agora',
'lien_nom_site' => 'NOME DEL SITIU:',
'lien_nouvelle_recuperation' => 'Tentar una nueva recuperaci&oacute;n de los datos',
'lien_reponse_article' => 'Respuesta a l\'art&iacute;culu',
'lien_reponse_breve' => 'Respuesta a la breve',
'lien_reponse_breve_2' => 'Respuesta a la breve',
'lien_reponse_rubrique' => 'Respuesta a la estaya',
'lien_reponse_site_reference' => 'Respuesta al sitiu referenci&aacute;u:',
'lien_retirer_auteur' => 'Retirar l\'autor',
'lien_retrait_particpant' => 'retirar esti participante',
'lien_site' => 'sitiu',
'lien_supprimer_rubrique' => 'desaniciar esta estaya',
'lien_tout_deplier' => 'Desplegalo too',
'lien_tout_replier' => 'Replegalo too',
'lien_tout_supprimer' => 'Desanicialo too',
'lien_trier_nom' => 'Ordenar pol nome',
'lien_trier_nombre_articles' => 'Ordenar pol n&uacute;mberu d\'art&iacute;culos',
'lien_trier_statut' => 'Ordenar pol estau',
'lien_voir_en_ligne' => 'VER EN LLINIA:',
'logo_article' => 'LOGO DE L\'ART&Iacute;CULU',
'logo_auteur' => 'LOGO DE L\'AUTOR O AUTORA',
'logo_breve' => 'LOGO DE LA BREVE',
'logo_mot_cle' => 'LOGO DE LA PALLABRA-CLAVE',
'logo_rubrique' => 'LOGO DE LA ESTAYA',
'logo_site' => 'LOGO D\'ESTI SITIU',
'logo_standard_rubrique' => 'LOGO EST&Aacute;NDAR DE LES ESTAYES',
'logo_survol' => 'LOGO AL PASAR EL MUR',

// M
'menu_aide_installation_choix_base' => 'Escoyeta de la base',
'module_fichier_langue' => 'Ficheru de ll&iacute;ngua',
'module_raccourci' => 'Atayu',
'module_texte_affiche' => 'Testu amosau',
'module_texte_explicatif' => 'Pues amestar los siguientes atayos nes cadarmes del sitiu p&uacute;blicu. Estos van traducise autom&aacute;ticamente a les diferentes lling&uuml;es pa les qu\'esista un archivu de llingua.',
'module_texte_traduction' => 'L\'archivu de llingua &laquo;&nbsp;@module@&nbsp;&raquo; ta disponible en:',
'mois_non_connu' => 'desconoc&iacute;u',

// N
'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW

// O
'onglet_contenu' => 'Conten&iacute;u',
'onglet_declarer_une_autre_base' => 'Declarar otra base',
'onglet_discuter' => 'Discutiniu',
'onglet_documents' => 'Documentos',
'onglet_interactivite' => 'Interactivid&aacute;',
'onglet_proprietes' => 'Propied&aacute;es',
'onglet_repartition_actuelle' => 'actualmente',
'onglet_sous_rubriques' => 'So-estayes',

// P
'page_pas_proxy' => 'Esta p&aacute;xina nun debe pasar pol proxy',
'pas_de_proxy_pour' => 'Si fai falta, indica les m&aacute;quines o dominios pa los que esti proxy nun debe aplicase (por exemplu: @exemple@)',
'plugin_charge_paquet' => 'Carga del paquete @name@',
'plugin_charger' => 'T&#233;l&#233;charger', # NEW
'plugin_erreur_charger' => 'fallu: nun ye posible cargar @zip@',
'plugin_erreur_droit1' => 'El direutoriu <code>@dest@</code> nun ye accesible pa escritura.',
'plugin_erreur_droit2' => 'Verifica los permisos d\'esti direutoriu (o cr&eacute;alu si ye\'l casu), o instala los archivos per FTP.',
'plugin_erreur_zip' => 'fall&oacute; pclzip col mensaxe: @status@',
'plugin_etat_developpement' => 'en desarrollu',
'plugin_etat_experimental' => 'esperimental',
'plugin_etat_stable' => 'estable',
'plugin_etat_test' => 'en prebes',
'plugin_impossible_activer' => 'Nun ye posible activar el plugin @plugin@',
'plugin_info_automatique1' => 'Si se quier autorizar la instalaci&oacute;n autom&aacute;tica de los plugins, hai que:',
'plugin_info_automatique1_lib' => 'Si vous souhaitez autoriser l\'installation automatique de cette librairie, veuillez&nbsp;:', # NEW
'plugin_info_automatique2' => 'crear un direutoriu <code>@rep@</code>&nbsp;;',
'plugin_info_automatique3' => 'verificar que\'l sirvidor tenga permisos pa escribir nesi direutoriu.',
'plugin_info_automatique_creer' => 'que hai que crear na raiz del sitiu.',
'plugin_info_automatique_exemples' => 'exemplos:',
'plugin_info_automatique_ftp' => 'Puedes instalar plugins, per FTP, nel direutoriu <tt>@rep@</tt>',
'plugin_info_automatique_lib' => 'Dellos plugins necesiten tambi&eacute;n permisu pa descargar archivos nel direutoriu <code>lib/</code>, a crear si ye\'l casu na raiz del sitiu.',
'plugin_info_automatique_liste' => 'Les tos llistes de plugins:',
'plugin_info_automatique_liste_officielle' => 'los plugins oficiales',
'plugin_info_automatique_liste_update' => 'Actualizar les llistes',
'plugin_info_automatique_ou' => 'o...',
'plugin_info_automatique_select' => 'Seleiciona un plugin d\'embaxo: SPIP va descargalu y anicialu nel direutoriu <code>@rep@</code>&nbsp;; si el plugin ya esiste, pondrase al d&iacute;a.',
'plugin_info_extension_1' => 'Les extensions ci-dessous sont charg&#233;es et activ&#233;es dans le r&#233;pertoire @extensions@.', # NEW
'plugin_info_extension_2' => 'Elles ne sont pas d&#233;sactivables.', # NEW
'plugin_info_telecharger' => 'a descargar de @url@ y a instalar en @rep@',
'plugin_librairies_installees' => 'Llibrer&iacute;es instal&aacute;es',
'plugin_necessite_lib' => 'Esti plugin necesita la llibrer&iacute;a @lib@',
'plugin_necessite_plugin' => 'Necesita el plugin @plugin@ en versi&oacute;n @version@ m&iacute;nimo.',
'plugin_necessite_spip' => 'Necesita SPIP en versi&oacute;n @version@ m&iacute;nimo.',
'plugin_source' => 'fonte:&nbsp;',
'plugin_titre_automatique' => 'Instalaci&oacute;n autom&aacute;tica',
'plugin_titre_automatique_ajouter' => 'Amestar plugins',
'plugin_titre_installation' => 'Installation du plugin @plugin@', # NEW
'plugin_zip_active' => 'Contin&uacute;a pa activalu',
'plugin_zip_adresse' => 'indica embaxo les se&ntilde;es d\'un archivu zip de plugin a descargar, o mesmo les se&ntilde;es d\'una llista de plugins.',
'plugin_zip_adresse_champ' => 'Se&ntilde;es del plugin o de la llista&nbsp;',
'plugin_zip_content' => 'Contien los archivos siguientes (@taille@),<br />preparaos pa instalase nel direutoriu <code>@rep@</code>',
'plugin_zip_installe_finie' => 'L\'archivu @zip@ descomprimiose y qued&oacute; instalau.',
'plugin_zip_installe_rep_finie' => 'L\'archivu @zip@ descomprimiose y qued&oacute; instalau nel direutoriu @rep@',
'plugin_zip_installer' => 'Pues instalalu agora.',
'plugin_zip_telecharge' => 'Descargose l\'archivu @zip@',
'plugins_actif_aucun' => 'Aucun plugin activ&#233;.', # NEW
'plugins_actif_un' => 'Un plugin activ&#233;.', # NEW
'plugins_actifs' => '@count@ plugins activaos.',
'plugins_actifs_liste' => 'Plugins actifs', # NEW
'plugins_compte' => '@count@ plugins',
'plugins_disponible_un' => 'Un plugin disponible.', # NEW
'plugins_disponibles' => '@count@ plugins disponibles.',
'plugins_erreur' => 'Error nos plugins: @plugins@',
'plugins_liste' => 'Llista de los plugins',
'plugins_liste_extensions' => 'Extensions', # NEW
'plugins_recents' => 'Plugins r&eacute;cents.', # NEW
'plugins_vue_hierarchie' => 'Xerarqu&iacute;a',
'plugins_vue_liste' => 'Llista',
'protocole_ldap' => 'Versi&oacute;n del protocolu:',

// R
'repertoire_plugins' => 'Direutoriu:',

// S
'sans_heure' => 'ensin hora',
'sauvegarde_fusionner' => 'Fusionar la base actual y la copia de segurid&aacute;',
'sauvegarde_fusionner_depublier' => 'Desespublizar los oxetos fusionaos',
'sauvegarde_url_origine' => 'Si ye\'l casu, URL del sitiu d\'orixe:',
'statut_admin_restreint' => '(almin llendau)',
'syndic_choix_moderation' => '&iquest;Que se fai colos pr&oacute;ximos enllaces que vengan d\'esti sitiu?',
'syndic_choix_oublier' => '&iquest;Qu&eacute; se fai colos enllaces que nun figuren nel archivu de sindicaci&oacute;n?',
'syndic_choix_resume' => 'Dellos sitios esparden el testu completu de los art&iacute;culos. Cuando el mesmu tea disponible quies sindicar:',
'syndic_lien_obsolete' => 'enllaz vieyu',
'syndic_option_miroir' => 'bloquialos autom&aacute;ticamente',
'syndic_option_oubli' => 'desanicialos (tres @mois@&nbsp;meses)',
'syndic_option_resume_non' => 'el conten&iacute;u ensembre de los art&iacute;culos (en formatu HTML)',
'syndic_option_resume_oui' => 'un simple resume (en formatu testu)',
'syndic_options' => 'Opciones de sindicaci&oacute;n:',

// T
'taille_cache_image' => 'Les imaxes calcul&aacute;es autom&aacute;ticamente por SPIP (miniatures de documentos, t&iacute;tulos en formatu gr&aacute;ficu, funciones matem&aacute;tiques en formatu TeX...) ocupen nel direutoriu @dir@ un total de @taille@.',
'taille_cache_infinie' => 'Esti sitiu nun conse&ntilde;a llendes de tama&ntilde;u pal direutoriu de cach&eacute;.',
'taille_cache_maxi' => 'SPIP tenta llendar el tama&ntilde;u del direutoriu de cach&eacute; d\'esti sitiu a unos <b>@octets@</b> de datos.',
'taille_cache_octets' => 'El tama&ntilde;u de cach&eacute; actualmente ye de @octets@.',
'taille_cache_vide' => 'La cach&eacute; ta vac&iacute;a.',
'taille_repertoire_cache' => 'Tama&ntilde;u del direutoriu de cach&eacute;',
'text_article_propose_publication' => 'Art&iacute;culu propuestu pa espublizase.',
'text_article_propose_publication_forum' => 'Encamentamoste a dar la to opini&oacute;n nel foru axuntu a esti art&iacute;culu (embaxo de la p&aacute;xina).',
'texte_acces_ldap_anonyme_1' => 'Dellos sirvidores LDAP nun acepten los accesos an&oacute;nimos. Si esti ye\'l casu hai que especificar una identificaci&oacute;n d\'accesu inicial a la fin de poder llu&eacute;u restolar la informaci&oacute;n na gu&iacute;a. Sicas&iacute;, nos m&aacute;s de los casos, los campos siguientes puen dexase vac&iacute;os.',
'texte_admin_effacer_01' => 'Esta orde desanicia <i>tol</i> conten&iacute;u de la base de datos,
incluy&iacute;os <i>tolos</i> accesos de redactores y alministradores. Tres d\'executalu, vas tener que llanzar la
reinstalaci&oacute;n de SPIP pa crear una nueva base igual que un primer accesu d\'alministrador.',
'texte_admin_effacer_stats' => 'Esta orde esborra tolos datos tocantes a les estad&iacute;stiques de visites al sitiu, incluyendo la popularid&aacute; de los art&iacute;culos.',
'texte_admin_tech_01' => 'Esta opci&oacute;n te permite facer copia del conten&iacute;u de la base nun archivu que va guardase nel direutoriu @dossier@. Tampoco nun escaezas recuperar ensembre el direutoriu @img@, que conti&eacute;n les imaxes y los documentos utilizaos nos art&iacute;culos y nes estayes.',
'texte_admin_tech_02' => 'Atenci&oacute;n: esta copia S&Oacute;LO va poder restaurase nun sitiu instal&aacute;u cola mesma versi&oacute;n de SPIP. Poro, y n\'especial, nun hai que &laquo;vaciar la base&raquo; cuntando con reinstalar la copia tres d\'una actualizaci&oacute;n... Consulta <a href="@spipnet@">la documentaci&oacute;n de SPIP</a>.',
'texte_admin_tech_03' => 'Pues escoyer guardar l\'archivu en forma comprimida, col env&iacute;s
 d\'amenorgar so tresferencia al to ordenador o a un sirvidor de copies de segurid&aacute;, y d\'aforrar l\'espaciu en discu.',
'texte_admin_tech_04' => 'Si se quier facer una fusi&oacute;n con otra base, pues llendar la copia a la estaya: ',
'texte_adresse_annuaire_1' => '(Si la gu&iacute;a ta instalada na mesma m&aacute;quina que esti sitiu Web, ye probablemente &laquo;localhost&raquo;.)',
'texte_ajout_auteur' => 'El siguiente autor amestose a l\'art&iacute;culu:',
'texte_annuaire_ldap_1' => 'Si ties accesu a una gu&iacute;a (LDAP), vas poder utilizala pa importar autom&aacute;ticamente usuarios a SPIP.',
'texte_article_statut' => 'Esti art&iacute;culu ta:',
'texte_article_virtuel' => 'Art&iacute;culu virtual',
'texte_article_virtuel_reference' => '<b>Art&iacute;culu virtual:</b> art&iacute;culu referenciau nel sitiu SPIP, magar que redirixe a otra URL. Pa desaniciar la redireici&oacute;n, esborra la URL d\'enriba.',
'texte_aucun_resultat_auteur' => 'Nun hai resultaos pa "@cherche_auteur@"',
'texte_auteur_messagerie' => 'Esti sitiu pue amosate de mou permanente la llista de redactores coneutaos, lo que te permite intercambiar mensaxes en direutu. Pues decidir nun apaecer nesa llista (ser &laquo;invisible&raquo; pa los dem&aacute;s usuarios).',
'texte_auteur_messagerie_1' => 'Esti sitiu permite l\'intercambiu de mensaxes y la constituci&oacute;n de foros de discutiniu privaos ente los participantes del sitiu. Pue decidir nun participar nos intercambios.',
'texte_auteurs' => 'LOS AUTORES',
'texte_breves' => 'Les breves son testos curtios y simples que permiten
 poner en llinia dafechu informaciones concises, xestionar
 una revista de prensa, una axenda de convocatories...',
'texte_choix_base_1' => 'Escueye la base de datos:',
'texte_choix_base_2' => 'El sirvidor SQL conti&eacute;n delles bases de datos.',
'texte_choix_base_3' => '<b>Seleiciona</b> de sigu&iacute;o la que te conse&ntilde;aren nel agospiamientu:',
'texte_choix_table_prefix' => 'Prefixu de les tables:',
'texte_commande_vider_tables_indexation' => 'Utiliza esta orde a la fin de vaciar les tables d\'indexaci&oacute;n utiliz&aacute;es
   pol motor de guetar integr&aacute;u con SPIP. Esto va permitite
   ganar espaciu nel discu.',
'texte_comment_lire_tableau' => 'El rangu de l\'art&iacute;culu,
  na clasificaci&oacute;n por popularid&aacute;, vi&eacute;n indic&aacute;u nel
  marxe; la popularid&aacute; de l\'art&iacute;culu (una estimaci&oacute;n del
  n&uacute;mberu de visites diaries que recibir&aacute; si el ritmu actual de
  consultes se mantuviere) y el n&uacute;mberu de visites recib&iacute;es
  dende\'l so espublizamientu amu&eacute;sense na burbuya
  que apaez al pasar el mur pol t&iacute;tulu.',
'texte_compacter_avertissement' => 'Cuida de nun activar estes opciones durante el desarrollo del sitiu: los elementos compactaos dexen dafechu de ser lleibles.',
'texte_compacter_script_css' => 'SPIP pue compautar los scripts JavaScript y les fueyes d\'estilu CSS, pa guardalos como archivos est&aacute;ticos; esto acelera l\'amosamientu del sitiu.',
'texte_compresse_ou_non' => '(esti pue tar comprim&iacute;u o non)',
'texte_compresseur_page' => 'SPIP pue comprimir autom&aacute;ticamente toles p&aacute;xines qu\'unv&iacute;a a los
visitantes del sitiu. Esti axuste permite optimizar l\'anchu de banda (el
sitiu ye m&aacute;s r&aacute;pidu tando tres d\'un enllaz de baxa capacid&aacute;), pero
requier m&aacute;s potencia del sirvidor.',
'texte_compte_element' => '@count@ elementu',
'texte_compte_elements' => '@count@ elementos',
'texte_config_groupe_mots_cles' => '&iquest;Quies activar la configuraci&oacute;n avanzada de les pallabres-clave,
   conse&ntilde;ando por exemplu que pue seleicionase una pallabra &uacute;nica
   por grupu, que un grupu ye importante...?',
'texte_conflit_edition_correction' => 'Compreba embaxo les diferencies ente les dos versiones del testu; tambi&eacute;n pues copiar los tos camb&eacute;os y, de sigu&iacute;o, volver a entamar',
'texte_connexion_mysql' => 'Consulta la informaci&oacute;n que te dieren nel to agospiamientu web: ties que atopar el sirvidor de base datos que te ufre y los c&oacute;digos de identificaci&oacute;n pa conectate.',
'texte_contenu_article' => '(Conten&iacute;u de l\'art&iacute;culu en delles pallabres.)',
'texte_contenu_articles' => 'Seg&uacute;n la maquetaci&oacute;n que uses pal to sitiu, seique decidas
  que dellos elementos de los art&iacute;culos nun van utilizase.
  Usa la llista d\'embaxo pa indicar los elementos que van tar disponibles.',
'texte_crash_base' => 'Si la to base de datos ta
   ca&iacute;da, pues tentar una reparaci&oacute;n
   autom&aacute;tica.',
'texte_creer_rubrique' => 'Enantes que puedas escribir art&iacute;culos,<br /> tienes que crear una estaya.',
'texte_date_creation_article' => 'FECHA DE CREACI&Oacute;N DE L\'ART&Iacute;CULU:',
'texte_date_publication_anterieure' => 'Fecha de redaici&oacute;n anterior:',
'texte_date_publication_anterieure_nonaffichee' => 'Nun amosar fecha de redaici&oacute;n anterior.',
'texte_date_publication_article' => 'FECHA D\'ESPUBLIZAMIENTU EN LLINIA:',
'texte_descriptif_petition' => 'Descripci&oacute;n de la solicit&uacute;',
'texte_descriptif_rapide' => 'Descripci&oacute;n r&aacute;pida',
'texte_documents_joints' => 'Pues autorizar l\'amiestu de documentos (archivos d\'oficina, imaxes,
 multimedia, etc.) a los art&iacute;culos y/o a les estayes. Estos archivos
 puen referenciase llu&eacute;u nel
 art&iacute;culu, o amosase aparte.', # MODIF
'texte_documents_joints_2' => 'Esti axuste nun torga l\'inxertu d\'imaxes direutamente nos art&iacute;culos.',
'texte_effacer_base' => 'Desaniciar la base de datos SPIP',
'texte_effacer_donnees_indexation' => 'Desaniciar los datos d\'indexaci&oacute;n',
'texte_effacer_statistiques' => 'Desaniciar les estad&iacute;stiques',
'texte_en_cours_validation' => 'Los art&iacute;culos y breves d\'embaxo tan propuestos pa espublizase.',
'texte_en_cours_validation_forum' => 'Encament&aacute;moste que opines usando los foros que tien xun&iacute;os.',
'texte_enrichir_mise_a_jour' => 'Pues arriquecer la paxinaci&oacute;n del testu utilizando los &laquo;atayos tipogr&aacute;ficos&raquo;.',
'texte_fichier_authent' => '<b>&iquest;Ti&eacute;n SPIP que crear los ficheros especiales <tt>.htpasswd</tt>
  y <tt>.htpasswd-admin</tt> na carpeta @dossier@?</b><p>
  Estes ficheros pueden sirvite pa torgar l\'accesu, tanto de los autores
  como de los administradores a otres partes del to sitiu web
  (al programa esternu d\'estad&iacute;stiques, por exemplu).</p><p>
  Si nun vas utilizalo, puedes dexar esta opci&oacute;n
 col so valor predetermin&aacute;u (nun crear
 esos ficheros).</p>', # MODIF
'texte_informations_personnelles_1' => 'Agora el sistema va create un accesu personaliz&aacute;u al sitiu.',
'texte_informations_personnelles_2' => '(Nota: si esto ye una reinstalaci&oacute;n, y el to accesu siempre funciona, pues',
'texte_introductif_article' => '(Testu d\'introducci&oacute;n de l\'art&iacute;culu.)',
'texte_jeu_caractere' => 'Encami&eacute;ntase emplegar, pal to sitiu, l\'alfabetu universal (<tt>utf-8</tt>): esti permite amosar los testos en toes les lling&uuml;es, y ya nun da problemes de compatibilid&aacute; colos &ntilde;avegadores modernos.',
'texte_jeu_caractere_2' => 'Atenci&oacute;n: esti axuste nun provoca la conversi&oacute;n de los testos que ya tean grabaos na base de datos.',
'texte_jeu_caractere_3' => 'Esti sitiu ta instal&aacute;u actualmente col xuegu de carauteres:',
'texte_jeu_caractere_4' => 'Si esto nun concasa cola realid&aacute; de los datos (siguir, por exemplu, tres d\'una restauraci&oacute;n de la base de datos), o si <em>tas arrancando esti sitiu</em> y quies entamar con otru xuegu de carauteres, conse&ntilde;a esti darr&eacute;u:',
'texte_jeu_caractere_conversion' => 'Nota: pues querer convertir d\'una vez por toes el conxuntu de testos d\'esti sitiu (art&iacute;culos, breves, foros, etc.) a l\'alfabetu <tt>utf-8</tt>, entrando na <a href="@url@">p&aacute;xina de conversi&oacute;n a l\'utf-8</a>.',
'texte_lien_hypertexte' => '(Si el to mensaxe refierse a un art&iacute;culu espubliz&aacute;u na Web, o a una p&aacute;xina que ufre m&aacute;s informaci&oacute;n, indica de sigu&iacute;o el t&iacute;tulu de la p&aacute;xina y les se&ntilde;es URL.)',
'texte_liens_sites_syndiques' => 'Los enllaces surd&iacute;os de los sitios sindicaos
   puen bloquiase a priori; l\'axuste de
   m&aacute;s embaxo indica l\'axuste por omisi&oacute;n de
   los sitios sindicaos tres de crease. Llueu
   ye posible, sicas&iacute;, desbloquiar cada
   enllaz individualmente, o escoyer, sitiu
   por sitiu, si bloquiar los enllaces que
   vengan de tal o cual sitiu.',
'texte_login_ldap_1' => '(Dexar vac&iacute;o pa un accesu an&oacute;nimu, o conse&ntilde;ar el cam&iacute;n ensembre, por exemplu &laquo;<tt>uid=dupont, ou=users, dc=mio-dominiu, dc=com</tt>&nbsp;&raquo;.)',
'texte_login_precaution' => '&iexcl;Atenci&oacute;n! Esti ye l\'usuariu col que tas coneutau actualmente.
 Utiliza esti formulariu con procuru...',
'texte_message_edit' => 'Atenci&oacute;n: esti mensaxe pue camudase por tolos alministradores del sitiu, y ye visible pa tolos redactores. Nun uses les anuncies m&aacute;s que pa amosar les activid&aacute;es importantes pa la vida del sitiu.',
'texte_messagerie_agenda' => 'Una mensaxer&iacute;a permite-yos a los redactores del sitiu comunicase direutamente ente ellos nel espaciu privau del sitiu. La mensaxer&iacute;a va asociada con una axenda.',
'texte_messages_publics' => 'Mensaxes p&uacute;blicos de l\'art&iacute;culu:',
'texte_mise_a_niveau_base_1' => 'Tas acabante de poner al d&iacute;a los archivos de SPIP.
 Agora fai falta actualizar la base de datos
 del sitiu.',
'texte_modifier_article' => 'Iguar l\'art&iacute;culu:',
'texte_moteur_recherche_active' => '<b>El motor de restolar ta activ&aacute;u.</b> Utiliza esta orde
  si quies entamar una reindexaci&oacute;n r&aacute;pida (tres la restauraci&oacute;n d\'una
  copia de segurid&aacute; por exemplu). Atalanta que los documentos modificaos
  de mou normal (dende la interfaz SPIP) reindexense autom&aacute;ticamente:
  esta orde, poro, nun ye afayadiza sinon de mou esceicional.',
'texte_moteur_recherche_non_active' => 'El motor de restolar nun ta activ&aacute;u.',
'texte_mots_cles' => 'Les pallabres-clave permiten crear enllaces tem&aacute;ticos ente art&iacute;culos
  independientemente del so allugamientu nes estayes. D\'esti mou pues
  arriquecer la &ntilde;avegacion pol sitiu, y utilizar estes propied&aacute;es
  pa personalizar la presentaci&oacute;n de los art&iacute;culos nes tos cadarmes.',
'texte_mots_cles_dans_forum' => '&iquest;Qui&eacute;s permitir l\'usu de pallabres-clave seleicionables polos visitantes nos foros del sitiu p&uacute;blicu? (Atenci&oacute;n: esta opci&oacute;n ye relativamente abegoso utilizala correutamente.)',
'texte_multilinguisme' => 'Si qui&eacute;s xuestionar art&iacute;culos en delles lling&uuml;es, con una &ntilde;avegaci&oacute;n complexa, pues amestar un men&uacute; de seleici&oacute;n de llingua nos articulos y/o nes estayes, al aldu de la organizaci&oacute;n del sitiu.',
'texte_multilinguisme_trad' => 'Igualmente pues activar un sistema de xesti&oacute;n de enllaces ente les distintes traducciones d\'un art&iacute;culu.',
'texte_non_compresse' => '<i>non comprim&iacute;u</i> (el to sirvidor nun soporta esta carauter&iacute;stica)',
'texte_non_fonction_referencement' => 'Seique prefieras nun usar esta funci&oacute;n autom&aacute;tica, y remanar t&uacute; mesmu los elementos tocantes a esti sitiu...',
'texte_nouveau_message' => 'Mensaxe nuevu',
'texte_nouveau_mot' => 'Pallabra nueva',
'texte_nouvelle_version_spip_1' => 'Vienes d\'instalar una versi&oacute;n nueva de SPIP.',
'texte_nouvelle_version_spip_2' => 'Esta nueva versi&oacute;n necesita una actualizaci&oacute;n m&aacute;s completa que la de vezu. Si yes el webmaster del sitiu, has d\'esborrar l\'archivu @connect@ y reentamar la instalaci&oacute;n pa actualizar los tos par&aacute;metros de conex&oacute;n a la base de datos.<p> (NB.: si escaeciste los tos par&aacute;metros de conex&oacute;n, echa-y una g&uuml;eyada a l\'archivu @connect@ enantes de desanicialu...)</p>', # MODIF
'texte_operation_echec' => 'Torna a la p&aacute;xina precedente, seleiciona otra base o crea una nueva. Compreba la informaci&oacute;n ufrida pol to agospiamientu web.',
'texte_plus_trois_car' => 'm&aacute;s de 3 carauteres',
'texte_plusieurs_articles' => 'Alcontr&aacute;ronse dellos autores pa "@cherche_auteur@":',
'texte_port_annuaire' => '(El valor indic&aacute;u por omisi&oacute;n convi&eacute;n polo xeneral.)',
'texte_presente_plugin' => 'Esta p&aacute;xina llista los plugins disponibles nel sitiu. Pues activar los plugins necesarios marcando el cuadru correspondiente.',
'texte_proposer_publication' => 'Cuando tea termin&aacute;u l\'art&iacute;culu,<br /> pues proponelu pa espublizar.',
'texte_proxy' => 'En ciertos casos (intranet, redes protex&iacute;es), los sitios esternos (documentaci&oacute;n de SPIP, sitios sindicaos, etc.) nun son accesibles m&aacute;s que al travi&eacute;s d\'un <i>proxy HTTP</i>. Si ye\'l casu, conse&ntilde;a embaxo les se&ntilde;es, na forma @proxy_en_cours@. En xeneral, esti cuadru d&eacute;xase vac&iacute;u.',
'texte_publication_articles_post_dates' => '&iquest;C&oacute;mo tien que comportase SPIP colos art&iacute;culos nos que la
  fecha d\'espublizamientu ta conse&ntilde;ada pa otru
  momentu futuru?',
'texte_rappel_selection_champs' => '[Nun escaezas seleicionar correutamente esti campu.]',
'texte_recalcul_page' => 'Si quies
recalcular una sola p&aacute;xina, pasa meyor pel espaciu p&uacute;blicu y calca nel bot&oacute;n &laquo;recalcular&raquo;.',
'texte_recapitiule_liste_documents' => 'Esta p&aacute;xina recapitula la llista de documentos que tienes allug&aacute;os nes estayes. Pa iguar la informaci&oacute;n de ca&uacute;n de los documentos, sigui l\'enllaz a la p&aacute;xina de la so estaya.',
'texte_recuperer_base' => 'Iguar la base de datos',
'texte_reference_mais_redirige' => 'art&iacute;culu referenci&aacute;u nel to sitiu SPIP, pero redirix&iacute;u a otra URL.',
'texte_referencement_automatique' => '<b>Referenciamientu automatiz&aacute;u d\'un sitiu</b><br />Pues referenciar r&aacute;pidamente un sitiu Web conse&ntilde;ando embaxo les se&ntilde;es URL dese&aacute;es, o les se&ntilde;es del so archivu de sindicaci&oacute;n. SPIP va recuperar autom&aacute;ticamente la informaci&oacute;n tocante a esti sitiu (t&iacute;tulu, descripci&oacute;n...).',
'texte_referencement_automatique_verifier' => 'Has de verificar la informaci&oacute;n ufrida por <tt>@url@</tt> enantes de grabar.',
'texte_requetes_echouent' => '<b>Cuando ciertes consultes SQL fallen
  sistem&aacute;ticamente y ensin raz&oacute;n aparente, ye
  posible que sea por cuenta de la mesma base
  de datos.</b><p>
  El sirvidor SQL ti&eacute;n la posibilid&aacute; d\'iguar les sos
  tables cuando estes tan da&ntilde;&aacute;es por
  accidente. Equ&iacute; pues tentar esta reparaci&oacute;n; en
  casu de fallu, guarda una copia del mensaxe, que tendr&aacute;,
  seique, indices de lo que nun funciona...</p><p>
  Si el problema persistiere, ponte en contautu col to
  agospiador.</p>', # MODIF
'texte_restaurer_base' => 'Restaurar el conten&iacute;u d\'una copia de segurid&aacute; de la base',
'texte_restaurer_sauvegarde' => 'Esta opci&oacute;n te permite restaurar una copia de segurid&aacute; de la base
  fecha anteriormente. Pa facer esto, l\'archivu que conti&eacute;n la copia de segurid&aacute; ti&eacute;n que tar
  allug&aacute;u nel direutoriu @dossier@.
  Ten prudencia con esta funcionalid&aacute;: <b>les modificaciones, y perdes si ye\'l casu, son
  irreversibles.</b>',
'texte_sauvegarde' => 'Facer copia de segurid&aacute; del conten&iacute;u de la base',
'texte_sauvegarde_base' => 'Facer copia de segurid&aacute; de la base',
'texte_sauvegarde_compressee' => 'La copia de segurid&aacute; va facese nel archivu non comprim&iacute;u @fichier@.',
'texte_selection_langue_principale' => 'M&aacute;s embaxo pues seleicionar la &laquo;llingua principal&raquo; del sitiu. Esti axuste nun te obliga - &iexcl;por suerte! - a escribir los art&iacute;culos na llingua seleicionada, sinon que permite afitar:
 <ul><li> el formatu por omisi&oacute;n de les feches pal sitiu p&uacute;blicu;</li>
 <li> la natura del motor tipogr&aacute;ficu que SPIP tien que utilizar pa representar los testos;</li>
 <li> la llingua utilizada nos formularios del sitiu p&uacute;blicu;</li>
 <li> la llingua por omisi&oacute;n pa presentar l\'espaciu priv&aacute;u.</li></ul>',
'texte_signification' => 'Les barres escures representen les entr&aacute;es acumul&aacute;es (total de les sub-estayes), les barres clares el n&uacute;mberu de visites pa cada estaya.',
'texte_sous_titre' => 'Subt&iacute;tulu',
'texte_statistiques_visites' => '(barres prietes:  domingu / curva prieta: evoluci&oacute;n de la media)',
'texte_statut_attente_validation' => 'esperando validaci&oacute;n',
'texte_statut_publies' => 'espublizaos en llinia',
'texte_statut_refuses' => 'refug&aacute;os',
'texte_suppression_fichiers' => 'Utilza esta orde pa desaniciar tolos archivos presentes
na cach&eacute; de SPIP. Esto permite por exemplu forzar un rec&aacute;lculu de toes les p&aacute;xines si
vienes de facer camb&eacute;os importantes nel grafismu o na estructura del sitiu.',
'texte_sur_titre' => 'Antet&iacute;tulu',
'texte_syndication' => 'Ye posible recuperar automaticamente, cuando un sitiu web lo permite,
  la llista de les noved&aacute;es. Para esto, hai que activar la sindicaci&oacute;n.
  <blockquote><i>Dellos agospiadores web desactiven esta funci&oacute;n;
  si ye\'l casu, nun vas poder usar la sindicaci&oacute;n de conten&iacute;os
  dende\'l to sitiu web.</i></blockquote>',
'texte_table_ok' => ': esta tabla ta bi&eacute;n.',
'texte_tables_indexation_vides' => 'Les tables d\'indexaci&oacute;n del motor tan vac&iacute;es.',
'texte_tentative_recuperation' => 'Intentu d\'igua',
'texte_tenter_reparation' => 'Tentar una reparaci&oacute;n de la base de datos',
'texte_test_proxy' => 'Pa facer una preba d\'esti proxy, conse&ntilde;a equ&iacute; les se&ntilde;es d\'un sitiu Web
    que quieras prebar.',
'texte_titre_02' => 'T&iacute;tulu:',
'texte_titre_obligatoire' => '<b>T&iacute;tulu</b> [Obligatorio]',
'texte_travail_article' => '@nom_auteur_modif@ trabay&oacute; nesti art&iacute;culu hai @date_diff@ minutos',
'texte_travail_collaboratif' => 'Si ye frecuente que dellos redactores
  trabayen nel mesmu art&iacute;culu, el sistema
  pue amosar los art&iacute;culos &laquo;abiertos&raquo; recientemente
  a la fin d\'evitar modificaciones simult&aacute;nees.
  Esta opci&oacute;n ta desactivada por omisi&oacute;n
  pa evitar l\'apaici&oacute;n de mensaxes d\'avisu
  intempestivos.',
'texte_trop_resultats_auteurs' => 'Abondos resultaos pa "@cherche_auteur@" ; has d\'afinar la gueta.',
'texte_type_urls' => 'Embaxo pues escoyer el mou de c&aacute;lculu de les se&ntilde;es de les p&aacute;xines.',
'texte_type_urls_attention' => 'Atenci&oacute;n esti axuste nun funcionar&aacute; m&aacute;s que si l\'archivu @htaccess@ ta correutamente instal&aacute;u na raiz del sitiu.',
'texte_unpack' => 'descarga de la versi&oacute;n cabera',
'texte_utilisation_moteur_syndiques' => 'Cuando uses el motor de restolar integr&aacute;u en
  SPIP, puedes facer les guetes nos sitios webs y
  nos art&iacute;culos sindicaos de dos maneres
  diferentes. <br />- La m&aacute;s
  cenciella consiste en restolar nam&aacute;i ente los
  t&iacute;tulos y descriciones de los art&iacute;culos.<br />-
  Un segundu m&eacute;todu, muncho m&aacute;s potente, perm&iacute;te-y
  a SPIP restolar ente\'l testu de los llugares
  referenciaos. Si referencies
  un sitiu web, SPIP va restolar tami&eacute;n ente\'l
  testu d\'esi sitiu web.',
'texte_utilisation_moteur_syndiques_2' => 'Esti m&eacute;todu obliga a que SPIP visite
    regularmente los sitios referenciaos,
    lo que pue provocar una lixera lentit&uacute; del propiu
    sitiu.',
'texte_vide' => 'vac&iacute;u',
'texte_vider_cache' => 'Vaciar la cach&eacute;',
'titre_admin_effacer' => 'Mantenimientu t&eacute;cnicu',
'titre_admin_tech' => 'Mantenimientu t&eacute;cnicu',
'titre_admin_vider' => 'Mantenimientu t&eacute;cnicu',
'titre_articles_syndiques' => 'Art&iacute;culos sindicaos vinientes d\'esti sitiu',
'titre_breves' => 'Les breves',
'titre_cadre_afficher_article' => 'Amosar los art&iacute;culos',
'titre_cadre_afficher_traductions' => 'Amosar l\'estau de les traducciones pa les lling&uuml;es siguientes:',
'titre_cadre_ajouter_auteur' => 'AMESTAR UN AUTOR:',
'titre_cadre_forum_administrateur' => 'Foru privau de los alministradores',
'titre_cadre_forum_interne' => 'Foru internu',
'titre_cadre_interieur_rubrique' => 'Dientro de la estaya',
'titre_cadre_numero_auteur' => 'AUTOR N&Uacute;MBERU',
'titre_cadre_signature_obligatoire' => '<b>Robla</b> [Obligatoria]<br />',
'titre_compacter_script_css' => 'Compautaci&oacute;n de los scripts y CSS',
'titre_compresser_flux_http' => 'Compresi&oacute;n del fluxu HTTP',
'titre_config_contenu_notifications' => 'Notificaciones',
'titre_config_contenu_prive' => 'Nel espaciu priv&aacute;u',
'titre_config_contenu_public' => 'Nel sitiu p&uacute;blicu',
'titre_config_fonctions' => 'Configuraci&oacute;n del sitiu',
'titre_config_forums_prive' => 'Foros de l’espaciu priv&aacute;u',
'titre_config_groupe_mots_cles' => 'Configuraci&oacute;n de los grupos de pallabres-clave',
'titre_configuration' => 'Configuraci&oacute;n del sitiu',
'titre_conflit_edition' => 'Conflictu durante la edici&oacute;n',
'titre_connexion_ldap' => 'Axustes: <b>La to conex&oacute;n LDAP</b>',
'titre_dernier_article_syndique' => 'Caberos art&iacute;culos sindicaos',
'titre_documents_joints' => 'Documentos axuntos',
'titre_evolution_visite' => 'Evoluci&oacute;n de les visites',
'titre_forum_suivi' => 'Siguir foros',
'titre_gauche_mots_edit' => 'PALLABRA N&Uacute;MBERU:',
'titre_groupe_mots' => 'GRUPU DE PALLABRES:',
'titre_langue_article' => 'LLINGUA DE L\'ARTICULU',
'titre_langue_breve' => 'LLINGUA DE LA BREVE',
'titre_langue_rubrique' => 'LLINGUA DE LA ESTAYA',
'titre_langue_trad_article' => 'LLINGUA Y TRADUCCIONES DE L\'ART&Iacute;CULU',
'titre_les_articles' => 'LOS ART&Iacute;CULOS',
'titre_messagerie_agenda' => 'Mensaxer&iacute;a y axenda',
'titre_mots_cles_dans_forum' => 'Pallabres-clave nos foros del sitiu p&uacute;blicu',
'titre_mots_tous' => 'Les pallabres-clave',
'titre_naviguer_dans_le_site' => '&Ntilde;avegar pol sitiu Web...',
'titre_nouveau_groupe' => 'Grupu nuevu',
'titre_nouvelle_breve' => 'Breve nueva',
'titre_nouvelle_rubrique' => 'Estaya nueva',
'titre_numero_rubrique' => 'ESTAYA N&Uacute;MBERU:',
'titre_page_admin_effacer' => 'Mantenimientu t&eacute;unicu: esborrar la base',
'titre_page_articles_edit' => 'Camudar: @titre@',
'titre_page_articles_page' => 'Los art&iacute;culos',
'titre_page_articles_tous' => 'Tou el sitiu',
'titre_page_auteurs' => 'Visitantes',
'titre_page_breves' => 'Breves',
'titre_page_breves_edit' => 'Cambear la breve: &laquo;@titre@&raquo;',
'titre_page_calendrier' => 'Axenda de @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Configuraci&oacute;n del sitiu',
'titre_page_config_fonctions' => 'Configuraci&oacute;n del sitiu',
'titre_page_configuration' => 'Configuraci&oacute;n del sitiu',
'titre_page_controle_petition' => 'Siguimientu de les solicitudes',
'titre_page_delete_all' => 'desaniciu total e irreversible',
'titre_page_documents_liste' => 'Los documentos de les estayes',
'titre_page_forum' => 'Foru de los alministradores',
'titre_page_forum_envoi' => 'Unviar un mensaxe',
'titre_page_forum_suivi' => 'Siguir los foros',
'titre_page_index' => 'El to espaciu priv&aacute;u',
'titre_page_message_edit' => 'Redactar un mensaxe',
'titre_page_messagerie' => 'La to mensaxer&iacute;a',
'titre_page_mots_tous' => 'Pallabres-clave',
'titre_page_recherche' => 'Resultaos de la gueta @recherche@',
'titre_page_sites_tous' => 'Los sitios referenciaos',
'titre_page_statistiques' => 'Estad&iacute;stiques por estayes',
'titre_page_statistiques_messages_forum' => 'Mensaxes de foros',
'titre_page_statistiques_referers' => 'Estad&iacute;stiques (enllaces entrantes)',
'titre_page_statistiques_signatures_jour' => 'N&uacute;mberu de robles por d&iacute;a',
'titre_page_statistiques_signatures_mois' => 'N&uacute;mberu de robles por mes',
'titre_page_statistiques_visites' => 'Estad&iacute;stiques de les visites',
'titre_page_upgrade' => 'Actualizaci&oacute;n de SPIP',
'titre_publication_articles_post_dates' => 'Publicaci&oacute;n d\'art&iacute;culos con fecha posterior',
'titre_referencement_sites' => 'Referenciaci&oacute;n de sitios y sindicaci&oacute;n',
'titre_referencer_site' => 'Referenciar el sitiu:',
'titre_rendez_vous' => 'CITES:',
'titre_reparation' => 'Igua',
'titre_site_numero' => 'SITIU N&Uacute;MBERU:',
'titre_sites_proposes' => 'Los sitios propuestos',
'titre_sites_references_rubrique' => 'Los sitios referenciaos na estaya',
'titre_sites_syndiques' => 'Los sitios sindicaos',
'titre_sites_tous' => 'Los sitios referenciaos',
'titre_suivi_petition' => 'Siguimientu de les solicitudes',
'titre_syndication' => 'Sindicaci&oacute;n de sitios',
'titre_type_urls' => 'Tipu de se&ntilde;es URL',
'tls_ldap' => 'Transport Layer Security (TLS):',
'tout_dossier_upload' => 'Tou el direutoriu @upload@',
'trad_article_inexistant' => 'Nun hay deng&uacute;n art&iacute;culu con esi n&uacute;mberu.',
'trad_article_traduction' => 'Toles versiones d\'esti art&iacute;culu:',
'trad_deja_traduit' => 'Fallu: nun ye posible rellacionar esti art&iacute;culu col n&uacute;mberu pid&iacute;u. ',
'trad_delier' => 'Ya nun enllazar esti art&iacute;culu coles sos traduciones ',
'trad_lier' => 'Esti art&iacute;culu ye una traduci&oacute;n del art&iacute;culu n&uacute;mberu:',
'trad_new' => 'Escribir una nueva torna d\'esti art&iacute;culu',

// U
'upload_fichier_zip' => 'Archivu ZIP',
'upload_fichier_zip_texte' => 'L\'archivu que quies instalar ye un archivu Zip.',
'upload_fichier_zip_texte2' => 'Esti archivu puede ser:',
'upload_info_mode_document' => 'Dexar esta imaxe nel maletu',
'upload_info_mode_image' => 'Desaniciar esta imaxe del maletu',
'upload_limit' => 'Esti archivu ye demasiao grande pal sirvidor; el mayor tama&ntilde;u de <i>subida</i> autorizao ye de @max@.',
'upload_zip_conserver' => 'Conservar l’archivu tres de la estraici&oacute;n',
'upload_zip_decompacter' => 'descomprim&iacute;u y ca&uacute;n de los elementos que contien instalarase nel sitiu. Los archivos que van instalase nel sitiu son:',
'upload_zip_telquel' => 'instal&aacute;u tal cual, como archivu Zip comprim&iacute;u;',
'upload_zip_titrer' => 'Titular seg&uacute;n el nome de los archivos',
'utf8_convert_attendez' => 'Espera dellos instantes y recarga esta p&aacute;xina.',
'utf8_convert_avertissement' => 'Disp&oacute;neste a convertir el conten&iacute;u de la to base de datos (art&iacute;culos, breves, etc) del xuegu de carauteres <b>@orig@</b> al xuegu de carauteres <b>@charset@</b>.',
'utf8_convert_backup' => 'Nun escaezas de facer enantes una copia de segurid&aacute; completa del to sitiu. Tambi&eacute;n tendr&iacute;es que verificar si les cadarmes y archivos de lling&uuml;es son compatibles con @charset@.',
'utf8_convert_erreur_deja' => 'Esti sitiu ya ta en @charset@, ye in&uacute;til facer la conversi&oacute;n...',
'utf8_convert_erreur_orig' => 'Error: el xuegu de caraut&eacute;res @charset@ nun ta soport&aacute;u.',
'utf8_convert_termine' => '&iexcl;Terminose!',
'utf8_convert_timeout' => '<b>Importante:</b> en casu de <i>timeout</i> del sirvidor, tendr&aacute;s que recargar la p&aacute;xina mientres que nun apaeza &laquo;terminao&raquo;.',
'utf8_convert_verifier' => 'Agora tienes que vaciar la cach&eacute;, y verificar que too se vea bien nes p&aacute;xines p&uacute;bliques del sitiu. En casu de problemes graves, f&iacute;zose una copia de segurid&aacute; de los datos (en formatu SQL) nel direutoriu @rep@.',
'utf8_convertir_votre_site' => 'Convertir esti sitiu a utf-8',

// V
'version' => 'Versi&oacute;n:',
'version_deplace_rubrique' => 'Desasiti&aacute;o de <b>&laquo;&nbsp;@from@&nbsp;&raquo;</b> pa <b>&laquo;&nbsp;@to@&nbsp;&raquo;</b>.',
'version_initiale' => 'Versi&oacute;n d\'entamu'
);

?>
